@@ -99,7 +99,7 @@ protected:
                              // performance reason
 private:
     unsigned int owner;
-#ifdef __SSE2__
+#ifdef ART_SIMD
     alignas(16) vfloat maxsv;
     alignas(16) vfloat sizev;
     alignas(16) vint sizeiv;
@@ -132,7 +132,7 @@ public:
         upperBound = size - 1;
         maxs = size - 2;
         maxsf = (float)maxs;
-#ifdef __SSE2__
+#ifdef ART_SIMD
         maxsv = F2V(maxs);
         sizeiv = _mm_set1_epi32((int)(size - 1));
         sizev = F2V(size - 1);
@@ -166,7 +166,7 @@ public:
         upperBound = size - 1;
         maxs = size - 2;
         maxsf = (float)maxs;
-#ifdef __SSE2__
+#ifdef ART_SIMD
         maxsv = F2V(maxs);
         sizeiv = _mm_set1_epi32((int)(size - 1));
         sizev = F2V(size - 1);
@@ -180,7 +180,7 @@ public:
     {
         data = nullptr;
         reset();
-#ifdef __SSE2__
+#ifdef ART_SIMD
         maxsv = ZEROV;
         sizev = ZEROV;
         sizeiv = _mm_setzero_si128();
@@ -236,7 +236,7 @@ public:
             this->upperBound = rhs.upperBound;
             this->maxs = this->size - 2;
             this->maxsf = (float)this->maxs;
-#ifdef __SSE2__
+#ifdef ART_SIMD
             this->maxsv = F2V(this->size - 2);
             this->sizeiv = _mm_set1_epi32((int)(this->size - 1));
             this->sizev = F2V(this->size - 1);
@@ -303,7 +303,7 @@ public:
         return data[rtengine::LIM<int>(index, 0, upperBound)];
     }
 
-#ifdef __SSE2__
+#ifdef ART_SIMD
 
     // NOTE: This function requires LUTs which clips only at lower bound
     vfloat cb(vfloat indexv) const
@@ -622,7 +622,7 @@ public:
         sum = 0.f;
         avg = 0.f;
         int i = 0;
-#ifdef __SSE2__
+#ifdef ART_SIMD
         vfloat iv = _mm_set_ps(3.f, 2.f, 1.f, 0.f);
         vfloat fourv = F2V(4.f);
         vint sumv = (vint)ZEROV;
@@ -677,7 +677,7 @@ public:
         upperBound = size - 1;
         maxs = size - 2;
         maxsf = (float)maxs;
-#ifdef __SSE2__
+#ifdef ART_SIMD
         maxsv = F2V(size - 2);
         sizeiv = _mm_set1_epi32((int)(size - 1));
         sizev = F2V(size - 1);
