@@ -47,7 +47,7 @@ void hphd_vertical(const array2D<float> &rawData, float **hpmap, int col_from,
     JaggedArray<float> dev(numCols, H, true);
 
     int k = col_from;
-#ifdef __SSE2__
+#ifdef ART_SIMD
     const vfloat ninev = F2V(9.f);
     const vfloat epsv = F2V(0.001f);
 #endif
@@ -67,7 +67,7 @@ void hphd_vertical(const array2D<float> &rawData, float **hpmap, int col_from,
         }
 
         for (int j = 4; j < H - 4; j++) {
-#ifdef __SSE2__
+#ifdef ART_SIMD
             // faster than #pragma omp simd...
             const vfloat avgL1 =
                 ((LVFU(temp[j - 4][0]) + LVFU(temp[j - 3][0])) +
@@ -191,7 +191,7 @@ void hphd_horizontal(const array2D<float> &rawData, float **hpmap, int row_from,
     memset(avg, 0, W * sizeof(float));
     memset(dev, 0, W * sizeof(float));
 
-#ifdef __SSE2__
+#ifdef ART_SIMD
     const vfloat onev = F2V(1.f);
     const vfloat twov = F2V(2.f);
     const vfloat zd8v = F2V(0.8f);
@@ -228,7 +228,7 @@ void hphd_horizontal(const array2D<float> &rawData, float **hpmap, int row_from,
         }
 
         int j = 5;
-#ifdef __SSE2__
+#ifdef ART_SIMD
         // faster than #pragma omp simd
         for (; j < W - 8; j += 4) {
             const vfloat avgL = LVFU(avg[j - 1]);
