@@ -266,7 +266,7 @@ void RawImageSource::lmmse_interpolate_omp(int winw, int winh,
 
         for (int rr = 4; rr < rr1 - 4; rr++) {
             int cc = 4 + (FC(rr, 4) & 1);
-#ifdef __SSE2__
+#ifdef ART_SIMD
             vfloat p1v, p2v, p3v, p4v, p5v, p6v, p7v, p8v, p9v, muv, vxv, vnv,
                 xhv, vhv, xvv, vvv;
             vfloat epsv = F2V(1e-7);
@@ -523,7 +523,7 @@ void RawImageSource::lmmse_interpolate_omp(int winw, int winh,
             for (int c = 0; c < 3; c += 2) {
                 int d = c + 3 - (c == 0 ? 0 : 1);
                 int cc = 1;
-#ifdef __SSE2__
+#ifdef ART_SIMD
 
                 for (; cc < cc1 - 4; cc += 4) {
                     rix[d] = qix[d] + rr * cc1 + cc;
@@ -731,7 +731,7 @@ void RawImageSource::refinement(int PassCount)
             for (int row = 2; row < height - 2; row++) {
                 int col = 2 + (FC(row, 2) & 1);
                 int c = FC(row, col);
-#ifdef __SSE2__
+#ifdef ART_SIMD
                 vfloat dLv, dRv, dUv, dDv, v0v;
                 vfloat onev = F2V(1.f);
                 vfloat zd5v = F2V(0.5f);
@@ -799,7 +799,7 @@ void RawImageSource::refinement(int PassCount)
             for (int row = 2; row < height - 2; row++) {
                 int col = 2 + (FC(row, 3) & 1);
                 int c = FC(row, col + 1);
-#ifdef __SSE2__
+#ifdef ART_SIMD
                 vfloat dLv, dRv, dUv, dDv, v0v;
                 vfloat onev = F2V(1.f);
                 vfloat zd5v = F2V(0.5f);
@@ -877,7 +877,7 @@ void RawImageSource::refinement(int PassCount)
             for (int row = 2; row < height - 2; row++) {
                 int col = 2 + (FC(row, 2) & 1);
                 int c = 2 - FC(row, col);
-#ifdef __SSE2__
+#ifdef ART_SIMD
                 vfloat dLv, dRv, dUv, dDv, v0v;
                 vfloat onev = F2V(1.f);
                 vfloat zd5v = F2V(0.5f);
@@ -942,7 +942,7 @@ void RawImageSource::refinement(int PassCount)
         } // end parallel
     }
 }
-#ifdef __SSE2__
+#ifdef ART_SIMD
 #undef CLIPV
 #endif
 
