@@ -1033,7 +1033,7 @@ __inline double xlog1p(double a)
 #define R_LN2f                                                                 \
     1.442695040888963407359924681001892137426645954152985934135449406931f
 
-#ifdef __SSE2__
+#if defined(__SSE2__) || defined(ART_USE_SIMDE)
 __inline int xrintf(float x) { return _mm_cvt_ss2si(_mm_set_ss(x)); }
 #else
 __inline int xrintf(float x) { return x + (x < 0 ? -0.5f : 0.5f); }
@@ -1160,7 +1160,7 @@ __inline float xsinf(float d)
 
 __inline float xcosf(float d)
 {
-#ifdef __SSE2__
+#if defined(__SSE2__) || defined(ART_USE_SIMDE)
     // faster than scalar version
     return xcosf(_mm_set_ss(d))[0];
 #else
@@ -1192,7 +1192,7 @@ __inline float xcosf(float d)
 
 __inline float2 xsincosf(float d)
 {
-#ifdef __SSE2__
+#if defined(__SSE2__) || defined(ART_USE_SIMDE)
     // faster than scalar version
     vfloat2 res = xsincosf(_mm_set_ss(d));
     return {res.x[0], res.y[0]};
