@@ -18,28 +18,27 @@
  *  along with ART.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <stdio.h>
+#include <giomm.h>
 #include <glib/gstdio.h>
 #include <iostream>
+#include <stdio.h>
 #include <unistd.h>
-#include <giomm.h>
 
 #include <set>
 
 #ifdef WIN32
-#  include <windows.h>
-#  include <io.h>
-#  include <fcntl.h>
+#include <windows.h>
+#include <fcntl.h>
+#include <io.h>
 #else
-#  include <sys/types.h>
-#  include <sys/wait.h>
-#  include <signal.h>
+#include <signal.h>
+#include <sys/types.h>
+#include <sys/wait.h>
 #endif
 
-#include "subprocess.h"
-#include "settings.h"
 #include "../rtgui/pathutils.h"
-
+#include "settings.h"
+#include "subprocess.h"
 
 namespace rtengine {
 
@@ -47,7 +46,6 @@ extern const Settings *settings;
 
 namespace subprocess {
 
-
 std::wstring to_wstr(const Glib::ustring &s)
 {
     auto *ws = g_utf8_to_utf16(s.c_str(), -1, nullptr, nullptr, nullptr);
@@ -56,7 +54,6 @@ std::wstring to_wstr(const Glib::ustring &s)
     return ret;
 }
 
-
 #ifdef WIN32
 
 std::vector<Glib::ustring> split_command_line(const Glib::ustring &cmdl)
@@ -65,14 +62,15 @@ std::vector<Glib::ustring> split_command_line(const Glib::ustring &cmdl)
     int n;
     LPWSTR *a = CommandLineToArgvW(w.c_str(), &n);
     if (!a) {
-        throw (error() << "impossible to split command line: " << cmdl);
+        throw(error() << "impossible to split command line: " << cmdl);
     }
-    
+
     std::vector<Glib::ustring> ret;
     for (int i = 0; i < n; ++i) {
-        auto *s = g_utf16_to_utf8(reinterpret_cast<gunichar2 *>(a[i]), -1, nullptr, nullptr, nullptr);
+        auto *s = g_utf16_to_utf8(reinterpret_cast<gunichar2 *>(a[i]), -1,
+                                  nullptr, nullptr, nullptr);
         if (!s) {
-            throw (error() << "impossible to split command line: " << cmdl);
+            throw(error() << "impossible to split command line: " << cmdl);
         }
         ret.push_back(s);
         g_free(s);
@@ -82,12 +80,11 @@ std::vector<Glib::ustring> split_command_line(const Glib::ustring &cmdl)
     return ret;
 }
 
-
 namespace {
 
 void add_quoted(std::wostream &out, const std::wstring &ws)
 {
-    for (size_t j = 0; j < ws.size(); ) {
+    for (size_t j = 0; j < ws.size();) {
         int backslashes = 0;
         while (j < ws.size() && ws[j] == '\\') {
             ++backslashes;
@@ -124,14 +121,15 @@ struct HandleCloser {
     std::set<HANDLE> toclose;
 };
 
-
 } // namespace
 
 // Glib::spawn_sync opens a console window for command-line apps, I wasn't
 // able to find out how not to do that (see also:
 // http://gtk.10911.n7.nabble.com/g-spawn-on-windows-td84743.html).
 // Therefore, we roll our own
-void exec_sync(const Glib::ustring &workdir, const std::vector<Glib::ustring> &argv, bool search_in_path, std::string *out, std::string *err)
+void exec_sync(const Glib::ustring &workdir,
+               const std::vector<Glib::ustring> &argv, bool search_in_path,
+               std::string *out, std::string *err)
 {
     // TODO - capturing stdout/stderr leads to ReadFile hanging sometimes on
     // windows. I still have to figure out why though. In the meantime, we
@@ -139,7 +137,7 @@ void exec_sync(const Glib::ustring &workdir, const std::vector<Glib::ustring> &a
     // informative purposes in verbose console output)
     out = nullptr;
     err = nullptr;
-    
+
     HANDLE fds_from[2];
     HANDLE fds_from_e[2];
     SECURITY_ATTRIBUTES sa;
@@ -149,23 +147,21 @@ void exec_sync(const Glib::ustring &workdir, const std::vector<Glib::ustring> &a
     sa.lpSecurityDescriptor = NULL;
     sa.bInheritHandle = TRUE;
 
-    const auto mkpipe =
-        [&](HANDLE *fd) -> bool
-        {
-            if (!CreatePipe(&(fd[0]), &(fd[1]), &sa, 0)) {
-                return false;
-            }
-            hc.toclose.insert(fd[0]);
-            hc.toclose.insert(fd[1]);
-            if (!SetHandleInformation(fd[0], HANDLE_FLAG_INHERIT, 0)) {
-                return false;
-            }
-            return true;
-        };
+    const auto mkpipe = [&](HANDLE *fd) -> bool {
+        if (!CreatePipe(&(fd[0]), &(fd[1]), &sa, 0)) {
+            return false;
+        }
+        hc.toclose.insert(fd[0]);
+        hc.toclose.insert(fd[1]);
+        if (!SetHandleInformation(fd[0], HANDLE_FLAG_INHERIT, 0)) {
+            return false;
+        }
+        return true;
+    };
 
     if (out || err) {
         if (!mkpipe(fds_from) || !mkpipe(fds_from_e)) {
-            throw (error() << "mkpipe failed");
+            throw(error() << "mkpipe failed");
         }
     }
 
@@ -184,9 +180,10 @@ void exec_sync(const Glib::ustring &workdir, const std::vector<Glib::ustring> &a
 
     std::wstring pth = to_wstr(argv[0]);
     if (search_in_path) {
-        wchar_t pathbuf[MAX_PATH+1];
+        wchar_t pathbuf[MAX_PATH + 1];
         std::wstring suffix = to_wstr(".exe");
-        int n = SearchPathW(nullptr, pth.c_str(), suffix.c_str(), MAX_PATH+1, pathbuf, nullptr);
+        int n = SearchPathW(nullptr, pth.c_str(), suffix.c_str(), MAX_PATH + 1,
+                            pathbuf, nullptr);
         if (n > 0) {
             pth = pathbuf;
         }
@@ -201,44 +198,41 @@ void exec_sync(const Glib::ustring &workdir, const std::vector<Glib::ustring> &a
             add_quoted(cmdlinebuf, to_wstr(argv[i]));
         }
         std::wstring s = cmdlinebuf.str();
-        cmdline = new wchar_t[s.size()+1];
+        cmdline = new wchar_t[s.size() + 1];
         memcpy(cmdline, s.c_str(), s.size() * sizeof(wchar_t));
         cmdline[s.size()] = 0;
     }
 
     std::wstring wd = to_wstr(workdir);
     if (!CreateProcessW(pth.c_str(), cmdline, nullptr, nullptr, TRUE,
-                        CREATE_NO_WINDOW,
-                        (LPVOID)nullptr, wd.empty() ? nullptr : wd.c_str(),
-                        &si, &pi)) {
+                        CREATE_NO_WINDOW, (LPVOID) nullptr,
+                        wd.empty() ? nullptr : wd.c_str(), &si, &pi)) {
         delete[] cmdline;
-        throw (error() << "impossible to create process");
+        throw(error() << "impossible to create process");
     } else {
         hc.toclose.insert(pi.hProcess);
         hc.toclose.insert(pi.hThread);
     }
     delete[] cmdline;
 
-    const auto read_pipe =
-        [&](HANDLE *fd) -> std::string
-        {
-            constexpr size_t bufsize = 4096;
-            unsigned char buf[bufsize];
-            std::ostringstream sbuf;
-            DWORD n;
+    const auto read_pipe = [&](HANDLE *fd) -> std::string {
+        constexpr size_t bufsize = 4096;
+        unsigned char buf[bufsize];
+        std::ostringstream sbuf;
+        DWORD n;
 
-            hc.toclose.erase(fd[1]);
-            CloseHandle(fd[1]);
+        hc.toclose.erase(fd[1]);
+        CloseHandle(fd[1]);
 
-            while (ReadFile(fd[0], buf, bufsize, &n, nullptr)) {
-                buf[n] = 0;
-                sbuf << buf;
-                if (n < bufsize) {
-                    break;
-                }
+        while (ReadFile(fd[0], buf, bufsize, &n, nullptr)) {
+            buf[n] = 0;
+            sbuf << buf;
+            if (n < bufsize) {
+                break;
             }
-            return sbuf.str();
-        };
+        }
+        return sbuf.str();
+    };
 
     if (out || err) {
         std::string o = read_pipe(fds_from);
@@ -261,11 +255,10 @@ void exec_sync(const Glib::ustring &workdir, const std::vector<Glib::ustring> &a
     }
 
     if (status != 0) {
-        throw (error() << "exit status: " << status);
+        throw(error() << "exit status: " << status);
     }
 }
 
-
 std::wstring quote(const std::wstring &s)
 {
     std::wostringstream out;
@@ -273,7 +266,6 @@ std::wstring quote(const std::wstring &s)
     return out.str();
 }
 
-
 class SubprocessData {
 public:
     SubprocessData() = default;
@@ -283,7 +275,7 @@ public:
             CloseHandle(h);
         }
     }
-    
+
     std::set<HANDLE> toclose;
     SECURITY_ATTRIBUTES sa;
     PROCESS_INFORMATION pi;
@@ -292,32 +284,29 @@ public:
     HANDLE child_out;
 };
 
-
 SubprocessData *D(uintptr_t impl)
 {
     return reinterpret_cast<SubprocessData *>(impl);
 }
 
-
 SubprocessInfo::~SubprocessInfo()
 {
     kill();
     delete D(impl_);
 }
 
-
 bool SubprocessInfo::live() const
 {
     DWORD exitcode = 0;
     return GetExitCodeProcess(D(impl_)->pi.hProcess, &exitcode) &&
-        exitcode == STILL_ACTIVE;
+           exitcode == STILL_ACTIVE;
 }
 
-
 int SubprocessInfo::wait()
 {
     const DWORD wait_timeout_ms = INFINITE;
-    if (WaitForSingleObject(D(impl_)->pi.hProcess, wait_timeout_ms) != WAIT_OBJECT_0) {
+    if (WaitForSingleObject(D(impl_)->pi.hProcess, wait_timeout_ms) !=
+        WAIT_OBJECT_0) {
         kill();
         return -1;
     }
@@ -326,46 +315,34 @@ int SubprocessInfo::wait()
     return status;
 }
 
-
-void SubprocessInfo::kill()
-{
-    TerminateProcess(D(impl_)->pi.hProcess, 255);
-}
-
+void SubprocessInfo::kill() { TerminateProcess(D(impl_)->pi.hProcess, 255); }
 
 int SubprocessInfo::read()
 {
-    char buf[1] = { 0 };
+    char buf[1] = {0};
     if (!ReadFile(D(impl_)->child_out, &buf, 1, nullptr, nullptr)) {
         return EOF;
     }
     return buf[0];
 }
 
-
 bool SubprocessInfo::write(const char *msg, size_t n)
 {
     DWORD w = 0;
     return WriteFile(D(impl_)->child_in, msg, n, &w, nullptr);
 }
 
+bool SubprocessInfo::flush() { return FlushFileBuffers(D(impl_)->child_in); }
 
-bool SubprocessInfo::flush()
-{
-    return FlushFileBuffers(D(impl_)->child_in);
-}
+int SubprocessInfo::id() const { return GetProcessId(D(impl_)->pi.hProcess); }
 
-
-int SubprocessInfo::id() const
-{
-    return GetProcessId(D(impl_)->pi.hProcess);
-}
-
-
-std::unique_ptr<SubprocessInfo> popen(const Glib::ustring &workdir, const std::vector<Glib::ustring> &argv, bool search_in_path, bool pipe_in, bool pipe_out)
+std::unique_ptr<SubprocessInfo> popen(const Glib::ustring &workdir,
+                                      const std::vector<Glib::ustring> &argv,
+                                      bool search_in_path, bool pipe_in,
+                                      bool pipe_out)
 {
     std::unique_ptr<SubprocessData> data(new SubprocessData());
-    
+
     HANDLE fds_to[2];
     HANDLE fds_from[2];
     SECURITY_ATTRIBUTES &sa = data->sa;
@@ -374,25 +351,23 @@ std::unique_ptr<SubprocessInfo> popen(const Glib::ustring &workdir, const std::v
     sa.lpSecurityDescriptor = NULL;
     sa.bInheritHandle = TRUE;
 
-    const auto mkpipe =
-        [&](HANDLE *fd, int direction) -> bool
-        {
-            if (!CreatePipe(&(fd[0]), &(fd[1]), &sa, 0)) {
-                return false;
-            }
-            data->toclose.insert(fd[0]);
-            data->toclose.insert(fd[1]);
-            if (!SetHandleInformation(fd[direction], HANDLE_FLAG_INHERIT, 0)) {
-                return false;
-            }
-            return true;
-        };
+    const auto mkpipe = [&](HANDLE *fd, int direction) -> bool {
+        if (!CreatePipe(&(fd[0]), &(fd[1]), &sa, 0)) {
+            return false;
+        }
+        data->toclose.insert(fd[0]);
+        data->toclose.insert(fd[1]);
+        if (!SetHandleInformation(fd[direction], HANDLE_FLAG_INHERIT, 0)) {
+            return false;
+        }
+        return true;
+    };
 
     if (pipe_in && !mkpipe(fds_to, 1)) {
-        throw (error() << "mkpipe failed");
+        throw(error() << "mkpipe failed");
     }
     if (pipe_out && !mkpipe(fds_from, 0)) {
-        throw (error() << "mkpipe failed");
+        throw(error() << "mkpipe failed");
     }
 
     PROCESS_INFORMATION &pi = data->pi;
@@ -418,9 +393,10 @@ std::unique_ptr<SubprocessInfo> popen(const Glib::ustring &workdir, const std::v
 
     std::wstring pth = to_wstr(argv[0]);
     if (search_in_path) {
-        wchar_t pathbuf[MAX_PATH+1];
+        wchar_t pathbuf[MAX_PATH + 1];
         std::wstring suffix = to_wstr(".exe");
-        int n = SearchPathW(nullptr, pth.c_str(), suffix.c_str(), MAX_PATH+1, pathbuf, nullptr);
+        int n = SearchPathW(nullptr, pth.c_str(), suffix.c_str(), MAX_PATH + 1,
+                            pathbuf, nullptr);
         if (n > 0) {
             pth = pathbuf;
         }
@@ -435,18 +411,17 @@ std::unique_ptr<SubprocessInfo> popen(const Glib::ustring &workdir, const std::v
             add_quoted(cmdlinebuf, to_wstr(argv[i]));
         }
         std::wstring s = cmdlinebuf.str();
-        cmdline = new wchar_t[s.size()+1];
+        cmdline = new wchar_t[s.size() + 1];
         memcpy(cmdline, s.c_str(), s.size() * sizeof(wchar_t));
         cmdline[s.size()] = 0;
     }
 
     std::wstring wd = to_wstr(workdir);
     if (!CreateProcessW(pth.c_str(), cmdline, nullptr, nullptr, TRUE,
-                        CREATE_NO_WINDOW,
-                        (LPVOID)nullptr, wd.empty() ? nullptr : wd.c_str(),
-                        &si, &pi)) {
+                        CREATE_NO_WINDOW, (LPVOID) nullptr,
+                        wd.empty() ? nullptr : wd.c_str(), &si, &pi)) {
         delete[] cmdline;
-        throw (error() << "impossible to create process");
+        throw(error() << "impossible to create process");
     } else {
         data->toclose.insert(pi.hProcess);
         data->toclose.insert(pi.hThread);
@@ -464,14 +439,14 @@ std::unique_ptr<SubprocessInfo> popen(const Glib::ustring &workdir, const std::v
     auto impl = data.release();
     impl->child_out = fds_from[0];
     impl->child_in = fds_to[1];
-    std::unique_ptr<SubprocessInfo> res(new SubprocessInfo(reinterpret_cast<uintptr_t>(impl)));
+    std::unique_ptr<SubprocessInfo> res(
+        new SubprocessInfo(reinterpret_cast<uintptr_t>(impl)));
 
     return res;
 }
 
 #else // WIN32
 
-
 std::vector<Glib::ustring> split_command_line(const Glib::ustring &cmdl)
 {
     try {
@@ -482,12 +457,13 @@ std::vector<Glib::ustring> split_command_line(const Glib::ustring &cmdl)
         }
         return ret;
     } catch (Glib::Error &e) {
-        throw (error() << e.what());
+        throw(error() << e.what());
     }
 }
 
-
-void exec_sync(const Glib::ustring &workdir, const std::vector<Glib::ustring> &argv, bool search_in_path, std::string *out, std::string *err)
+void exec_sync(const Glib::ustring &workdir,
+               const std::vector<Glib::ustring> &argv, bool search_in_path,
+               std::string *out, std::string *err)
 {
     std::vector<std::string> args;
     args.reserve(argv.size());
@@ -501,16 +477,16 @@ void exec_sync(const Glib::ustring &workdir, const std::vector<Glib::ustring> &a
             flags |= Glib::SPAWN_SEARCH_PATH;
         }
         std::string wd = Glib::filename_from_utf8(workdir);
-        Glib::spawn_sync(wd, args, get_env(), flags, Glib::SlotSpawnChildSetup(), out, err, &exit_status);
+        Glib::spawn_sync(wd, args, get_env(), flags,
+                         Glib::SlotSpawnChildSetup(), out, err, &exit_status);
         if (!(WIFEXITED(exit_status) && WEXITSTATUS(exit_status) == 0)) {
-            throw (error() << "exit status: " << exit_status);
+            throw(error() << "exit status: " << exit_status);
         }
     } catch (Glib::Exception &e) {
-        throw (error() << e.what());
+        throw(error() << e.what());
     }
 }
 
-
 class SubprocessData {
 public:
     SubprocessData() = default;
@@ -526,18 +502,12 @@ public:
     pid_t pid;
 };
 
-
 SubprocessData *D(uintptr_t impl)
 {
     return reinterpret_cast<SubprocessData *>(impl);
 }
 
-
-SubprocessInfo::~SubprocessInfo()
-{
-    delete D(impl_);
-}
-
+SubprocessInfo::~SubprocessInfo() { delete D(impl_); }
 
 bool SubprocessInfo::live() const
 {
@@ -550,7 +520,6 @@ bool SubprocessInfo::live() const
     }
 }
 
-
 int SubprocessInfo::wait()
 {
     int status = 0;
@@ -563,7 +532,6 @@ int SubprocessInfo::wait()
     }
 }
 
-
 void SubprocessInfo::kill()
 {
     if (live()) {
@@ -571,31 +539,30 @@ void SubprocessInfo::kill()
     }
 }
 
-
 int SubprocessInfo::read()
 {
-    char buf[1] = { 0 };
-    if (::read(D(impl_)->child_out, buf, 1) <= 0) { 
+    char buf[1] = {0};
+    if (::read(D(impl_)->child_out, buf, 1) <= 0) {
         return EOF;
     }
     return buf[0];
 }
 
-
 bool SubprocessInfo::write(const char *msg, size_t n)
 {
     return ::write(D(impl_)->child_in, msg, n) >= 0;
 }
 
-
 bool SubprocessInfo::flush()
 {
     fsync(D(impl_)->child_in);
     return true;
 }
 
-
-std::unique_ptr<SubprocessInfo> popen(const Glib::ustring &workdir, const std::vector<Glib::ustring> &argv, bool search_in_path, bool pipe_in, bool pipe_out)
+std::unique_ptr<SubprocessInfo> popen(const Glib::ustring &workdir,
+                                      const std::vector<Glib::ustring> &argv,
+                                      bool search_in_path, bool pipe_in,
+                                      bool pipe_out)
 {
     int fds_to[2];
     int fds_from[2];
@@ -605,24 +572,25 @@ std::unique_ptr<SubprocessInfo> popen(const Glib::ustring &workdir, const std::v
 
     std::string executable = "";
     if (argv.empty()) {
-        throw (error() << "invalid arguments");
+        throw(error() << "invalid arguments");
     } else {
         if (!search_in_path) {
             executable = argv[0];
         } else {
             executable = Glib::find_program_in_path(argv[0]);
-            if (!Glib::file_test(executable, Glib::FILE_TEST_IS_EXECUTABLE) && argv[0].find('/') == Glib::ustring::npos && !workdir.empty()) {
+            if (!Glib::file_test(executable, Glib::FILE_TEST_IS_EXECUTABLE) &&
+                argv[0].find('/') == Glib::ustring::npos && !workdir.empty()) {
                 executable = Glib::build_filename(workdir, argv[0]);
             }
         }
         if (!Glib::file_test(executable, Glib::FILE_TEST_IS_EXECUTABLE)) {
-            throw (error() << "executable not found: " << argv[0]);
+            throw(error() << "executable not found: " << argv[0]);
         }
     }
-    
+
     if (pipe_in) {
         if (pipe(fds_to) != 0) {
-            throw (error() << "pipe failed");
+            throw(error() << "pipe failed");
         } else {
             data->toclose.insert(fds_to[0]);
             data->toclose.insert(fds_to[1]);
@@ -630,7 +598,7 @@ std::unique_ptr<SubprocessInfo> popen(const Glib::ustring &workdir, const std::v
     }
     if (pipe_out) {
         if (pipe(fds_from) != 0) {
-            throw (error() << "pipe failed");
+            throw(error() << "pipe failed");
         } else {
             data->toclose.insert(fds_from[0]);
             data->toclose.insert(fds_from[1]);
@@ -643,7 +611,7 @@ std::unique_ptr<SubprocessInfo> popen(const Glib::ustring &workdir, const std::v
     pid_t pid = data->pid;
 
     if (pid < 0) {
-        throw (error() << "fork failed");
+        throw(error() << "fork failed");
     } else if (pid == 0) {
         /* child */
         if (pipe_in) {
@@ -663,14 +631,14 @@ std::unique_ptr<SubprocessInfo> popen(const Glib::ustring &workdir, const std::v
             chdir(workdir.c_str());
         }
 
-        std::vector<char *> args_vec(argv.size()+1);
+        std::vector<char *> args_vec(argv.size() + 1);
         for (size_t i = 0; i < argv.size(); ++i) {
             args_vec[i] = const_cast<char *>(argv[i].c_str());
         }
         args_vec.back() = nullptr;
         auto args = &args_vec[0];
 
-        std::vector<char *> env_vec(env.size()+1);
+        std::vector<char *> env_vec(env.size() + 1);
         for (size_t i = 0; i < env.size(); ++i) {
             env_vec[i] = const_cast<char *>(env[i].c_str());
         }
@@ -678,7 +646,7 @@ std::unique_ptr<SubprocessInfo> popen(const Glib::ustring &workdir, const std::v
         auto envp = &env_vec[0];
 
         execve(executable.c_str(), args, envp);
-        
+
         if (pipe_in) {
             close(0);
         }
@@ -700,21 +668,16 @@ std::unique_ptr<SubprocessInfo> popen(const Glib::ustring &workdir, const std::v
     auto impl = data.release();
     impl->child_in = fds_to[1];
     impl->child_out = fds_from[0];
-    
+
     res.reset(new SubprocessInfo(reinterpret_cast<uintptr_t>(impl)));
 
     return res;
 }
 
-
-int SubprocessInfo::id() const
-{
-    return D(impl_)->pid;
-}
+int SubprocessInfo::id() const { return D(impl_)->pid; }
 
 #endif // WIN32
 
-
 std::vector<std::string> get_env()
 {
     std::vector<std::string> ret;
@@ -739,5 +702,5 @@ std::vector<std::string> get_env()
     return ret;
 }
 
-
-}} // namespace rtengine::subprocess
+} // namespace subprocess
+} // namespace rtengine
