@@ -60,7 +60,7 @@ void RawImageSource::cielab(const float (*rgb)[3], float *l, float *a, float *b,
         return;
     }
 
-#ifdef __SSE2__
+#ifdef ART_SIMD
     vfloat c116v = F2V(116.f);
     vfloat c16v = F2V(16.f);
     vfloat c500v = F2V(500.f);
@@ -72,11 +72,11 @@ void RawImageSource::cielab(const float (*rgb)[3], float *l, float *a, float *b,
             xyz_camv[i][j] = F2V(xyz_cam[i][j]);
         }
 
-#endif // __SSE2__
+#endif // ART_SIMD
 
     for (int i = 0; i < height; i++) {
         int j = 0;
-#ifdef __SSE2__
+#ifdef ART_SIMD
 
         for (; j < labWidth - 3; j += 4) {
             vfloat redv, greenv, bluev;
@@ -859,7 +859,7 @@ void RawImageSource::xtrans_interpolate(const int passes, const bool useCieLab)
                         float(*yuv)[ts - 8][ts - 8] =
                             lab; // we use the lab buffer, which has the same
                                  // dimensions
-#ifdef __SSE2__
+#ifdef ART_SIMD
                         vfloat zd2627v = F2V(0.2627f);
                         vfloat zd6780v = F2V(0.6780f);
                         vfloat zd0593v = F2V(0.0593f);
@@ -869,7 +869,7 @@ void RawImageSource::xtrans_interpolate(const int passes, const bool useCieLab)
 
                         for (int row = 4; row < mrow - 4; row++) {
                             int col = 4;
-#ifdef __SSE2__
+#ifdef ART_SIMD
 
                             for (; col < mcol - 7; col += 4) {
                                 // use ITU-R BT.2020 YPbPr, which is great, but
@@ -925,7 +925,7 @@ void RawImageSource::xtrans_interpolate(const int passes, const bool useCieLab)
                 }
 
             /* Build homogeneity maps from the derivatives:         */
-#ifdef __SSE2__
+#ifdef ART_SIMD
                 vfloat eightv = F2V(8.f);
                 vfloat zerov = F2V(0.f);
                 vfloat onev = F2V(1.f);
@@ -933,7 +933,7 @@ void RawImageSource::xtrans_interpolate(const int passes, const bool useCieLab)
 
                 for (int row = 6; row < mrow - 6; row++) {
                     int col = 6;
-#ifdef __SSE2__
+#ifdef ART_SIMD
 
                     for (; col < mcol - 9; col += 4) {
                         vfloat tr1v = vminf(LVFU(drv[0][row - 5][col - 5]),
@@ -1023,7 +1023,7 @@ void RawImageSource::xtrans_interpolate(const int passes, const bool useCieLab)
                 for (int d = 0; d < ndir; d++) {
                     for (int row = MIN(top, 8); row < mrow - 8; row++) {
                         int col = startcol;
-#ifdef __SSE2__
+#ifdef ART_SIMD
                         int endcol = row < mrow - 9 ? mcol - 8 : mcol - 23;
 
                         // crunching 16 values at once is faster than summing up
@@ -1083,13 +1083,13 @@ void RawImageSource::xtrans_interpolate(const int passes, const bool useCieLab)
             // calculate maximum of homogeneity maps per pixel. Vectorized
             // calculation is a tiny bit faster than on the fly calculation in
             // next step
-#ifdef __SSE2__
+#ifdef ART_SIMD
                 vint maskv = _mm_set1_epi8(31);
 #endif
 
                 for (int row = MIN(top, 8); row < mrow - 8; row++) {
                     int col = startcol;
-#ifdef __SSE2__
+#ifdef ART_SIMD
                     int endcol = row < mrow - 9 ? mcol - 8 : mcol - 23;
 
                     for (; col < endcol; col += 16) {
