@@ -19,36 +19,36 @@
 #include "crophandler.h"
 #undef THREAD_PRIORITY_NORMAL
 
-#include <cstring>
-#include "guiutils.h"
-#include "cropwindow.h"
-#include "imagearea.h"
 #include "../rtengine/dcrop.h"
+#include "../rtengine/gauss.h"
+#include "../rtengine/improcfun.h"
 #include "../rtengine/refreshmap.h"
 #include "../rtengine/rt_math.h"
-#include "../rtengine/improcfun.h"
-#include "../rtengine/gauss.h"
+#include "cropwindow.h"
+#include "guiutils.h"
+#include "imagearea.h"
+#include <cstring>
 
 #include "../rtengine/threadpool.h"
 
 #ifdef _OPENMP
-# include <omp.h>
+#include <omp.h>
 #endif
 
 using namespace rtengine;
 
 namespace {
 
-
-Glib::RefPtr<Gdk::Pixbuf> resize_fast(Glib::RefPtr<Gdk::Pixbuf> src, int dw, int dh, float scale)
+Glib::RefPtr<Gdk::Pixbuf> resize_fast(Glib::RefPtr<Gdk::Pixbuf> src, int dw,
+                                      int dh, float scale)
 {
     auto dst = Gdk::Pixbuf::create(Gdk::COLORSPACE_RGB, false, 8, dw, dh);
     src->scale(dst, 0, 0, dw, dh, 0, 0, scale, scale, Gdk::INTERP_NEAREST);
     return dst;
 }
 
-
-Glib::RefPtr<Gdk::Pixbuf> resize_lanczos(Glib::RefPtr<Gdk::Pixbuf> src, int dw, int dh, float scale)
+Glib::RefPtr<Gdk::Pixbuf> resize_lanczos(Glib::RefPtr<Gdk::Pixbuf> src, int dw,
+                                         int dh, float scale)
 {
     const int sW = src->get_width();
     const int sH = src->get_height();
@@ -57,9 +57,9 @@ Glib::RefPtr<Gdk::Pixbuf> resize_lanczos(Glib::RefPtr<Gdk::Pixbuf> src, int dw,
     tmps.assignMode(Imagefloat::Mode::LAB);
     auto s_data = src->get_pixels();
     auto s_stride = src->get_rowstride();
-        
+
 #ifdef _OPENMP
-#   pragma omp parallel for
+#pragma omp parallel for
 #endif
     for (int y = 0; y < sH; ++y) {
         auto s_row = s_data + (y * s_stride);
@@ -78,14 +78,14 @@ Glib::RefPtr<Gdk::Pixbuf> resize_lanczos(Glib::RefPtr<Gdk::Pixbuf> src, int dw,
     auto dst = Gdk::Pixbuf::create(Gdk::COLORSPACE_RGB, false, 8, dw, dh);
     auto d_data = dst->get_pixels();
     auto d_stride = dst->get_rowstride();
-    
+
 #ifdef _OPENMP
-#   pragma omp parallel for
+#pragma omp parallel for
 #endif
     for (int y = 0; y < dh; ++y) {
         auto d_row = d_data + (y * d_stride);
         for (int x = 0; x < dw; ++x) {
-            d_row[x * 3] = LIM(int(tmpd.r(y, x)), 0, 255); 
+            d_row[x * 3] = LIM(int(tmpd.r(y, x)), 0, 255);
             d_row[x * 3 + 1] = LIM(int(tmpd.g(y, x)), 0, 255);
             d_row[x * 3 + 2] = LIM(int(tmpd.b(y, x)), 0, 255);
         }
@@ -94,7 +94,6 @@ Glib::RefPtr<Gdk::Pixbuf> resize_lanczos(Glib::RefPtr<Gdk::Pixbuf> src, int dw,
     return dst;
 }
 
-
 void sharpen_for_display(Glib::RefPtr<Gdk::Pixbuf> src, int skip)
 {
     if (skip <= 1) {
@@ -109,15 +108,15 @@ void sharpen_for_display(Glib::RefPtr<Gdk::Pixbuf> src, int skip)
     auto s_data = src->get_pixels();
     auto s_stride = src->get_rowstride();
 
-    const double sigma = 0.5 * 2.0/double(skip);
+    const double sigma = 0.5 * 2.0 / double(skip);
     const float amount = 0.8;
 
 #ifdef _OPENMP
-#   pragma omp parallel
+#pragma omp parallel
 #endif
     {
 #ifdef _OPENMP
-#       pragma omp for
+#pragma omp for
 #endif
         for (int y = 0; y < sH; ++y) {
             auto s_row = s_data + (y * s_stride);
@@ -129,91 +128,71 @@ void sharpen_for_display(Glib::RefPtr<Gdk::Pixbuf> src, int skip)
         gaussianBlur(buf, buf, sW, sH, sigma);
 
 #ifdef _OPENMP
-#       pragma omp for
+#pragma omp for
 #endif
         for (int y = 0; y < sH; ++y) {
             auto s_row = s_data + (y * s_stride);
             for (int x = 0; x < sW; ++x) {
                 float diff = s_row[x * 3 + 1] - buf[y][x];
-                s_row[x * 3 + 1] = LIM(int(s_row[x * 3 + 1] + diff * amount), 0, 255);
+                s_row[x * 3 + 1] =
+                    LIM(int(s_row[x * 3 + 1] + diff * amount), 0, 255);
             }
         }
     }
 }
 
-
-Glib::RefPtr<Gdk::Pixbuf> resample_preview(Glib::RefPtr<Gdk::Pixbuf> src, int dw, int dh, float scale, int skip)
+Glib::RefPtr<Gdk::Pixbuf> resample_preview(Glib::RefPtr<Gdk::Pixbuf> src,
+                                           int dw, int dh, float scale,
+                                           int skip)
 {
-    if (scale > 1.f || options.preview_resampling_quality == Options::PreviewResamplingQuality::LOW) {
+    if (scale > 1.f || options.preview_resampling_quality ==
+                           Options::PreviewResamplingQuality::LOW) {
         src = resize_fast(src, dw, dh, scale);
     } else if (scale < 1.f) {
         src = resize_lanczos(src, dw, dh, scale);
     }
-    if (options.preview_resampling_quality == Options::PreviewResamplingQuality::HIGH) {
+    if (options.preview_resampling_quality ==
+        Options::PreviewResamplingQuality::HIGH) {
         sharpen_for_display(src, skip);
     }
     return src;
 }
 
-
 } // namespace
 
-
-CropHandler::CropHandler() :
-    zoom(100),
-    ww(0),
-    wh(0),
-    cax(-1),
-    cay(-1),
-    cx(0),
-    cy(0),
-    cw(0),
-    ch(0),
-    cropX(0),
-    cropY(0),
-    cropW(0),
-    cropH(0),
-    enabled(false),
-    cropimg_width(0),
-    cropimg_height(0),
-    cix(0),
-    ciy(0),
-    ciw(0),
-    cih(0),
-    cis(1),
-    ipc(nullptr),
-    crop(nullptr),
-    displayHandler(nullptr),
-    redraw_needed(false),
-    initial(false)
+CropHandler::CropHandler()
+    : zoom(100), ww(0), wh(0), cax(-1), cay(-1), cx(0), cy(0), cw(0), ch(0),
+      cropX(0), cropY(0), cropW(0), cropH(0), enabled(false), cropimg_width(0),
+      cropimg_height(0), cix(0), ciy(0), ciw(0), cih(0), cis(1), ipc(nullptr),
+      crop(nullptr), displayHandler(nullptr), redraw_needed(false),
+      initial(false)
 {
 }
 
-
 CropHandler::~CropHandler()
 {
     idle_register.destroy();
 
     if (ipc) {
-        ipc->delSizeListener (this);
+        ipc->delSizeListener(this);
     }
 
-    setEnabled (false);
+    setEnabled(false);
 
     if (crop) {
-        //crop->destroy ();
+        // crop->destroy ();
         delete crop; // will do the same than destroy, plus delete the object
         crop = nullptr;
     }
 }
 
-void CropHandler::setEditSubscriber (EditSubscriber* newSubscriber)
+void CropHandler::setEditSubscriber(EditSubscriber *newSubscriber)
 {
     (static_cast<rtengine::Crop *>(crop))->setEditSubscriber(newSubscriber);
 }
 
-
-void CropHandler::newImage(std::shared_ptr<StagedImageProcessor> ipc_, bool isDetailWindow)
+void CropHandler::newImage(std::shared_ptr<StagedImageProcessor> ipc_,
+                           bool isDetailWindow)
 {
     ipc = ipc_;
     cx = 0;
@@ -224,24 +203,27 @@ void CropHandler::newImage(std::shared_ptr<StagedImageProcessor> ipc_, bool isDe
     }
 
     EditDataProvider *editDataProvider = nullptr;
-    CropWindow *cropWin = displayHandler ? static_cast<CropWindow*>(displayHandler) : nullptr;
+    CropWindow *cropWin =
+        displayHandler ? static_cast<CropWindow *>(displayHandler) : nullptr;
 
     if (cropWin) {
         editDataProvider = cropWin->getImageArea();
     }
 
-    crop = ipc->createCrop (editDataProvider, isDetailWindow);
-    ipc->setSizeListener (this);
-    crop->setListener (enabled ? this : nullptr);
+    crop = ipc->createCrop(editDataProvider, isDetailWindow);
+    ipc->setSizeListener(this);
+    crop->setListener(enabled ? this : nullptr);
     initial = true;
 }
 
-void CropHandler::sizeChanged(int x, int y, int ow, int oh)    // the ipc notifies it to keep track size changes like rotation
+void CropHandler::sizeChanged(
+    int x, int y, int ow,
+    int oh) // the ipc notifies it to keep track size changes like rotation
 {
-    compDim ();
+    compDim();
 }
 
-bool CropHandler::isFullDisplay ()
+bool CropHandler::isFullDisplay()
 {
     int w, h;
     getFullImageSize(w, h);
@@ -251,27 +233,27 @@ bool CropHandler::isFullDisplay ()
     return cropW == w && cropH == h;
 }
 
-double CropHandler::getFitCropZoom ()
+double CropHandler::getFitCropZoom()
 {
-    double z1 = (double) wh / cropParams.h;
-    double z2 = (double) ww / cropParams.w;
+    double z1 = (double)wh / cropParams.h;
+    double z2 = (double)ww / cropParams.w;
     return z1 < z2 ? z1 : z2;
 }
 
-double CropHandler::getFitZoom ()
+double CropHandler::getFitZoom()
 {
     if (ipc) {
-        double z1 = (double) wh / ipc->getFullHeight ();
-        double z2 = (double) ww / ipc->getFullWidth ();
+        double z1 = (double)wh / ipc->getFullHeight();
+        double z2 = (double)ww / ipc->getFullWidth();
         return z1 < z2 ? z1 : z2;
     } else {
         return 1.0;
     }
 }
 
-void CropHandler::setZoom (int z, int centerx, int centery)
+void CropHandler::setZoom(int z, int centerx, int centery)
 {
-    //assert (ipc);
+    // assert (ipc);
     if (!ipc) {
         return;
     }
@@ -285,7 +267,7 @@ void CropHandler::setZoom (int z, int centerx, int centery)
     int oldcay = cay;
 
     if (centerx == -1) {
-        cax = ipc->getFullWidth () / 2;
+        cax = ipc->getFullWidth() / 2;
     } else {
         float distToAnchor = float(cax - centerx);
         distToAnchor = distToAnchor / newScale * oldScale;
@@ -293,7 +275,7 @@ void CropHandler::setZoom (int z, int centerx, int centery)
     }
 
     if (centery == -1) {
-        cay = ipc->getFullHeight () / 2;
+        cay = ipc->getFullHeight() / 2;
     } else {
         float distToAnchor = float(cay - centery);
         distToAnchor = distToAnchor / newScale * oldScale;
@@ -316,30 +298,30 @@ void CropHandler::setZoom (int z, int centerx, int centery)
     cx = cax - cw / 2;
     cy = cay - ch / 2;
 
-
     int oldCropX = cropX;
     int oldCropY = cropY;
     int oldCropW = cropW;
     int oldCropH = cropH;
 
-    compDim ();
+    compDim();
 
-    bool needed = enabled && (oldZoom != zoom || oldcax != cax || oldcay != cay || oldCropX != cropX || oldCropY != cropY || oldCropW != cropW || oldCropH != cropH);
+    bool needed =
+        enabled && (oldZoom != zoom || oldcax != cax || oldcay != cay ||
+                    oldCropX != cropX || oldCropY != cropY ||
+                    oldCropW != cropW || oldCropH != cropH);
 
     if (needed) {
-        const auto doit =
-            [this,needsFullRefresh]() -> bool
-            {
-                if (ipc) {
-                    if (needsFullRefresh && !ipc->getHighQualComputed()) {
-                        ipc->startProcessing(M_HIGHQUAL);
-                        ipc->setHighQualComputed();
-                    } else {
-                        update ();
-                    }
+        const auto doit = [this, needsFullRefresh]() -> bool {
+            if (ipc) {
+                if (needsFullRefresh && !ipc->getHighQualComputed()) {
+                    ipc->startProcessing(M_HIGHQUAL);
+                    ipc->setHighQualComputed();
+                } else {
+                    update();
                 }
-                return false;
-            };
+            }
+            return false;
+        };
 
         if (zoom_conn_.connected()) {
             zoom_conn_.disconnect();
@@ -351,10 +333,13 @@ void CropHandler::setZoom (int z, int centerx, int centery)
             cropPixbuftrue.clear();
         }
 
-        zoom_conn_ = Glib::signal_timeout().connect(sigc::slot<bool>(doit), options.adjusterMaxDelay);
+        zoom_conn_ = Glib::signal_timeout().connect(sigc::slot<bool>(doit),
+                                                    options.adjusterMaxDelay);
     }
-    
-    // if (enabled && (oldZoom != zoom || oldcax != cax || oldcay != cay || oldCropX != cropX || oldCropY != cropY || oldCropW != cropW || oldCropH != cropH)) {
+
+    // if (enabled && (oldZoom != zoom || oldcax != cax || oldcay != cay ||
+    // oldCropX != cropX || oldCropY != cropY || oldCropW != cropW || oldCropH
+    // != cropH)) {
     //     if (needsFullRefresh && !ipc->getHighQualComputed()) {
     //         cropPixbuf.clear ();
     //         ipc->startProcessing(M_HIGHQUAL);
@@ -363,10 +348,9 @@ void CropHandler::setZoom (int z, int centerx, int centery)
     //         update ();
     //     }
     // }
-
 }
 
-float CropHandler::getZoomFactor ()
+float CropHandler::getZoomFactor()
 {
     if (zoom >= 1000) {
         return zoom / 1000;
@@ -375,8 +359,7 @@ float CropHandler::getZoomFactor ()
     }
 }
 
-
-void CropHandler::setWSize (int w, int h)
+void CropHandler::setWSize(int w, int h)
 {
 
     ww = w;
@@ -390,91 +373,85 @@ void CropHandler::setWSize (int w, int h)
         ch = wh * (zoom / 10);
     }
 
-    compDim ();
+    compDim();
 
     if (enabled) {
-        update ();
+        update();
     }
 }
 
-void CropHandler::getWSize (int& w, int &h)
+void CropHandler::getWSize(int &w, int &h)
 {
 
     w = ww;
     h = wh;
 }
 
-void CropHandler::getAnchorPosition (int& x, int& y)
+void CropHandler::getAnchorPosition(int &x, int &y)
 {
     x = cax;
     y = cay;
 }
 
-void CropHandler::setAnchorPosition (int x, int y, bool update_)
+void CropHandler::setAnchorPosition(int x, int y, bool update_)
 {
     cax = x;
     cay = y;
 
-    compDim ();
+    compDim();
 
     if (enabled && update_) {
-        update ();
+        update();
     }
 }
 
-void CropHandler::moveAnchor (int deltaX, int deltaY, bool update_)
+void CropHandler::moveAnchor(int deltaX, int deltaY, bool update_)
 {
     cax += deltaX;
     cay += deltaY;
 
-    compDim ();
+    compDim();
 
     if (enabled && update_) {
-        update ();
+        update();
     }
 }
 
-void CropHandler::centerAnchor (bool update_)
+void CropHandler::centerAnchor(bool update_)
 {
-    assert (ipc);
+    assert(ipc);
 
-    // Computes the crop's size and position given the anchor's position and display size
+    // Computes the crop's size and position given the anchor's position and
+    // display size
 
     cax = ipc->getFullWidth() / 2;
     cay = ipc->getFullHeight() / 2;
 
-    compDim ();
+    compDim();
 
     if (enabled && update_) {
-        update ();
+        update();
     }
 }
 
-void CropHandler::getPosition (int& x, int& y)
+void CropHandler::getPosition(int &x, int &y)
 {
 
     x = cropX;
     y = cropY;
 }
 
-
 void CropHandler::setDetailedCrop(
-    IImage8* im,
-    IImage8* imtrue,
-    const rtengine::procparams::ColorManagementParams& cmp,
-    const rtengine::procparams::CropParams& cp,
-    int ax,
-    int ay,
-    int aw,
-    int ah,
-    int askip
-)
+    IImage8 *im, IImage8 *imtrue,
+    const rtengine::procparams::ColorManagementParams &cmp,
+    const rtengine::procparams::CropParams &cp, int ax, int ay, int aw, int ah,
+    int askip)
 {
     if (!enabled) {
         return;
     }
 
-    cimg.lock ();
+    cimg.lock();
 
     cropParams = cp;
     colorParams = cmp;
@@ -487,9 +464,10 @@ void CropHandler::setDetailedCrop(
         cropimgtrue.clear();
     }
 
-    if (ax == cropX && ay == cropY && aw == cropW && ah == cropH && askip == (zoom >= 1000 ? 1 : zoom / 10)) {
-        cropimg_width = im->getWidth ();
-        cropimg_height = im->getHeight ();
+    if (ax == cropX && ay == cropY && aw == cropW && ah == cropH &&
+        askip == (zoom >= 1000 ? 1 : zoom / 10)) {
+        cropimg_width = im->getWidth();
+        cropimg_height = im->getHeight();
         const std::size_t cropimg_size = 3 * cropimg_width * cropimg_height;
         cropimg.assign(im->getData(), im->getData() + cropimg_size);
         cropimgtrue.assign(imtrue->getData(), imtrue->getData() + cropimg_size);
@@ -502,82 +480,92 @@ void CropHandler::setDetailedCrop(
         bool expected = false;
 
         if (redraw_needed.compare_exchange_strong(expected, true)) {
-            idle_register.add(
-                [this]() -> bool
-                {
-                    cimg.lock ();
+            idle_register.add([this]() -> bool {
+                cimg.lock();
 
-                    if (redraw_needed.exchange(false)) {
-                        cropPixbuf.clear ();
-                        cropPixbuftrue.clear ();
+                if (redraw_needed.exchange(false)) {
+                    cropPixbuf.clear();
+                    cropPixbuftrue.clear();
 
-                        if (!enabled) {
-                            cropimg.clear();
-                            cropimgtrue.clear();
-                            cimg.unlock ();
-                            return false;
-                        }
-
-                        if (!cropimg.empty()) {
-                            if (cix == cropX && ciy == cropY && ciw == cropW && cih == cropH && cis == (zoom >= 1000 ? 1 : zoom / 10)) {
-                                // calculate final image size
-                                float czoom = zoom >= 1000 ?
-                                    zoom / 1000.f :
-                                    float((zoom/10) * 10) / float(zoom);
-                                int imw = cropimg_width * czoom;
-                                int imh = cropimg_height * czoom;
-
-                                if (imw > ww) {
-                                    imw = ww;
-                                }
-
-                                if (imh > wh) {
-                                    imh = wh;
-                                }
-
-                                cropPixbuf = Gdk::Pixbuf::create_from_data (cropimg.data(), Gdk::COLORSPACE_RGB, false, 8, cropimg_width, cropimg_height, 3 * cropimg_width);
-                                cropPixbuf = resample_preview(cropPixbuf, imw, imh, czoom, cis);
-                                // if (czoom < 1.f) {
-                                //     cropPixbuf = resize_lanczos(cropPixbuf, imw, imh, czoom);
-                                // } else if (czoom > 1.f) {
-                                //     cropPixbuf = resize_fast(cropPixbuf, imw, imh, czoom);
-                                // }
-
-                                // sharpen_for_display(cropPixbuf, cis);
-
-                                cropPixbuftrue = Gdk::Pixbuf::create_from_data (cropimgtrue.data(), Gdk::COLORSPACE_RGB, false, 8, cropimg_width, cropimg_height, 3 * cropimg_width);
-                                if (czoom != 1.f) {
-                                    cropPixbuftrue = resize_fast(cropPixbuftrue, imw, imh, czoom);
-                                }
-                            }
-
-                            cropimg.clear();
-                            cropimgtrue.clear();
-                        }
-
-                        cimg.unlock ();
-
-                        if (displayHandler) {
-                            displayHandler->cropImageUpdated ();
-
-                            if (initial.exchange(false)) {
-                                displayHandler->initialImageArrived ();
-                            }
-                        }
-                    } else {
+                    if (!enabled) {
+                        cropimg.clear();
+                        cropimgtrue.clear();
                         cimg.unlock();
+                        return false;
                     }
 
-                    return false;
+                    if (!cropimg.empty()) {
+                        if (cix == cropX && ciy == cropY && ciw == cropW &&
+                            cih == cropH &&
+                            cis == (zoom >= 1000 ? 1 : zoom / 10)) {
+                            // calculate final image size
+                            float czoom =
+                                zoom >= 1000
+                                    ? zoom / 1000.f
+                                    : float((zoom / 10) * 10) / float(zoom);
+                            int imw = cropimg_width * czoom;
+                            int imh = cropimg_height * czoom;
+
+                            if (imw > ww) {
+                                imw = ww;
+                            }
+
+                            if (imh > wh) {
+                                imh = wh;
+                            }
+
+                            cropPixbuf = Gdk::Pixbuf::create_from_data(
+                                cropimg.data(), Gdk::COLORSPACE_RGB, false, 8,
+                                cropimg_width, cropimg_height,
+                                3 * cropimg_width);
+                            cropPixbuf = resample_preview(cropPixbuf, imw, imh,
+                                                          czoom, cis);
+                            // if (czoom < 1.f) {
+                            //     cropPixbuf = resize_lanczos(cropPixbuf, imw,
+                            //     imh, czoom);
+                            // } else if (czoom > 1.f) {
+                            //     cropPixbuf = resize_fast(cropPixbuf, imw,
+                            //     imh, czoom);
+                            // }
+
+                            // sharpen_for_display(cropPixbuf, cis);
+
+                            cropPixbuftrue = Gdk::Pixbuf::create_from_data(
+                                cropimgtrue.data(), Gdk::COLORSPACE_RGB, false,
+                                8, cropimg_width, cropimg_height,
+                                3 * cropimg_width);
+                            if (czoom != 1.f) {
+                                cropPixbuftrue = resize_fast(cropPixbuftrue,
+                                                             imw, imh, czoom);
+                            }
+                        }
+
+                        cropimg.clear();
+                        cropimgtrue.clear();
+                    }
+
+                    cimg.unlock();
+
+                    if (displayHandler) {
+                        displayHandler->cropImageUpdated();
+
+                        if (initial.exchange(false)) {
+                            displayHandler->initialImageArrived();
+                        }
+                    }
+                } else {
+                    cimg.unlock();
                 }
-            );
+
+                return false;
+            });
         }
     }
 
-    cimg.unlock ();
+    cimg.unlock();
 }
 
-void CropHandler::getWindow(int& cwx, int& cwy, int& cww, int& cwh, int& cskip)
+void CropHandler::getWindow(int &cwx, int &cwy, int &cww, int &cwh, int &cskip)
 {
     cwx = cropX;
     cwy = cropY;
@@ -593,17 +581,19 @@ void CropHandler::getWindow(int& cwx, int& cwy, int& cww, int& cwh, int& cskip)
         cwh = 32;
     }
 
-    cskip = zoom >= 1000 ? 1 : zoom/10;
+    cskip = zoom >= 1000 ? 1 : zoom / 10;
 }
 
-void CropHandler::update ()
+void CropHandler::update()
 {
 
     if (crop && enabled) {
-//        crop->setWindow (cropX, cropY, cropW, cropH, zoom>=1000 ? 1 : zoom); --> we use the "getWindow" hook instead of setting the size before
-        crop->setListener (this);
+        //        crop->setWindow (cropX, cropY, cropW, cropH, zoom>=1000 ? 1 :
+        //        zoom); --> we use the "getWindow" hook instead of setting the
+        //        size before
+        crop->setListener(this);
         cimg.lock();
-        cropPixbuf.clear ();
+        cropPixbuf.clear();
         cropPixbuftrue.clear();
         cimg.unlock();
 
@@ -612,12 +602,9 @@ void CropHandler::update ()
             auto i = ipc; // keep a reference around so that ipc doesn't get
                           // destroyed
             auto c = crop;
-            const auto upd =
-                [i, c]() -> void
-                {
-                    c->fullUpdate();
-                };
-            rtengine::ThreadPool::add_task(rtengine::ThreadPool::Priority::HIGH, upd);
+            const auto upd = [i, c]() -> void { c->fullUpdate(); };
+            rtengine::ThreadPool::add_task(rtengine::ThreadPool::Priority::HIGH,
+                                           upd);
         }
     }
 }
@@ -629,7 +616,7 @@ void CropHandler::setEnabled(bool e, bool do_update)
 
     if (!enabled) {
         if (crop) {
-            crop->setListener (nullptr);
+            crop->setListener(nullptr);
         }
 
         cimg.lock();
@@ -642,16 +629,15 @@ void CropHandler::setEnabled(bool e, bool do_update)
     }
 }
 
-bool CropHandler::getEnabled ()
+bool CropHandler::getEnabled() { return enabled; }
+
+void CropHandler::colorPick(const rtengine::Coord &pickerPos, float &r,
+                            float &g, float &b, float &rpreview,
+                            float &gpreview, float &bpreview,
+                            LockableColorPicker::Size size)
 {
 
-    return enabled;
-}
-
-void CropHandler::colorPick (const rtengine::Coord &pickerPos, float &r, float &g, float &b, float &rpreview, float &gpreview, float &bpreview, LockableColorPicker::Size size)
-{
-
-    //MyMutex::MyLock lock(cimg);
+    // MyMutex::MyLock lock(cimg);
 
     if (!cropPixbuf || !cropPixbuftrue) {
         r = g = b = 0.f;
@@ -663,9 +649,11 @@ void CropHandler::colorPick (const rtengine::Coord &pickerPos, float &r, float &
     int ySize = (int)size;
     int pixbufW = cropPixbuftrue->get_width();
     int pixbufH = cropPixbuftrue->get_height();
-    rtengine::Coord topLeftPos(pickerPos.x - xSize/2, pickerPos.y - ySize/2);
+    rtengine::Coord topLeftPos(pickerPos.x - xSize / 2,
+                               pickerPos.y - ySize / 2);
 
-    if (topLeftPos.x > pixbufW || topLeftPos.y > pixbufH || topLeftPos.x + xSize < 0 || topLeftPos.y + ySize < 0) {
+    if (topLeftPos.x > pixbufW || topLeftPos.y > pixbufH ||
+        topLeftPos.x + xSize < 0 || topLeftPos.y + ySize < 0) {
         return;
     }
 
@@ -690,20 +678,20 @@ void CropHandler::colorPick (const rtengine::Coord &pickerPos, float &r, float &
     }
 
     // Accumulating the data
-    std::uint32_t r2=0, g2=0, b2=0;
+    std::uint32_t r2 = 0, g2 = 0, b2 = 0;
     std::uint32_t count = 0;
-    const guint8* data = cropPixbuftrue->get_pixels();
-    for (int j = topLeftPos.y ; j < topLeftPos.y + ySize ; ++j) {
-        const guint8* data2 = data + cropPixbuftrue->get_rowstride()*j;
-        for (int i = topLeftPos.x ; i < topLeftPos.x + xSize ; ++i) {
-            const guint8* data3 = data2 + i*3;
+    const guint8 *data = cropPixbuftrue->get_pixels();
+    for (int j = topLeftPos.y; j < topLeftPos.y + ySize; ++j) {
+        const guint8 *data2 = data + cropPixbuftrue->get_rowstride() * j;
+        for (int i = topLeftPos.x; i < topLeftPos.x + xSize; ++i) {
+            const guint8 *data3 = data2 + i * 3;
             rtengine::Coord currPos(i, j);
             rtengine::Coord delta = pickerPos - currPos;
             rtengine::PolarCoord p(delta);
             if (p.radius <= radius) {
                 r2 += *data3;
-                g2 += *(data3+1);
-                b2 += *(data3+2);
+                g2 += *(data3 + 1);
+                b2 += *(data3 + 2);
                 ++count;
             }
         }
@@ -716,20 +704,20 @@ void CropHandler::colorPick (const rtengine::Coord &pickerPos, float &r, float &
     b = (float)b2 / (float)count / 255.f;
 
     // Accumulating the data
-    r2=0, g2=0, b2=0;
+    r2 = 0, g2 = 0, b2 = 0;
     count = 0;
     data = cropPixbuf->get_pixels();
-    for (int j = topLeftPos.y ; j < topLeftPos.y + ySize ; ++j) {
-        const guint8* data2 = data + cropPixbuf->get_rowstride()*j;
-        for (int i = topLeftPos.x ; i < topLeftPos.x + xSize ; ++i) {
-            const guint8* data3 = data2 + i*3;
+    for (int j = topLeftPos.y; j < topLeftPos.y + ySize; ++j) {
+        const guint8 *data2 = data + cropPixbuf->get_rowstride() * j;
+        for (int i = topLeftPos.x; i < topLeftPos.x + xSize; ++i) {
+            const guint8 *data3 = data2 + i * 3;
             rtengine::Coord currPos(i, j);
             rtengine::Coord delta = pickerPos - currPos;
             rtengine::PolarCoord p(delta);
             if (p.radius <= radius) {
                 r2 += *data3;
-                g2 += *(data3+1);
-                b2 += *(data3+2);
+                g2 += *(data3 + 1);
+                b2 += *(data3 + 2);
                 ++count;
             }
         }
@@ -742,54 +730,55 @@ void CropHandler::colorPick (const rtengine::Coord &pickerPos, float &r, float &
     bpreview = (float)b2 / (float)count / 255.f;
 }
 
-void CropHandler::getSize (int& w, int& h)
+void CropHandler::getSize(int &w, int &h)
 {
 
     w = cropW;
     h = cropH;
 }
 
-void CropHandler::getFullImageSize (int& w, int& h)
+void CropHandler::getFullImageSize(int &w, int &h)
 {
     if (ipc) {
-        w = ipc->getFullWidth ();
-        h = ipc->getFullHeight ();
+        w = ipc->getFullWidth();
+        h = ipc->getFullHeight();
     } else {
         w = h = 0;
     }
 }
 
-void CropHandler::compDim ()
+void CropHandler::compDim()
 {
-    assert (ipc && displayHandler);
+    assert(ipc && displayHandler);
 
-    // Computes the crop's size and position given the anchor's position and display size
+    // Computes the crop's size and position given the anchor's position and
+    // display size
 
     int fullW = ipc->getFullWidth();
     int fullH = ipc->getFullHeight();
     int imgX = -1, imgY = -1;
-    //int scaledFullW, scaledFullH;
+    // int scaledFullW, scaledFullH;
     int scaledCAX, scaledCAY;
     int wwImgSpace;
     int whImgSpace;
 
-    cax = rtengine::LIM(cax, 0, fullW-1);
-    cay = rtengine::LIM(cay, 0, fullH-1);
+    cax = rtengine::LIM(cax, 0, fullW - 1);
+    cay = rtengine::LIM(cay, 0, fullH - 1);
 
     if (zoom >= 1000) {
-        wwImgSpace = int(float(ww) / float(zoom/1000) + 0.5f);
-        whImgSpace = int(float(wh) / float(zoom/1000) + 0.5f);
-        //scaledFullW = fullW * (zoom/1000);
-        //scaledFullH = fullH * (zoom/1000);
-        scaledCAX = cax * (zoom/1000);
-        scaledCAY = cay * (zoom/1000);
+        wwImgSpace = int(float(ww) / float(zoom / 1000) + 0.5f);
+        whImgSpace = int(float(wh) / float(zoom / 1000) + 0.5f);
+        // scaledFullW = fullW * (zoom/1000);
+        // scaledFullH = fullH * (zoom/1000);
+        scaledCAX = cax * (zoom / 1000);
+        scaledCAY = cay * (zoom / 1000);
     } else {
-        wwImgSpace = int(float(ww) * (float(zoom)/10.f) + 0.5f);
-        whImgSpace = int(float(wh) * (float(zoom)/10.f) + 0.5f);
-        //scaledFullW = fullW / zoom;
-        //scaledFullH = fullH / zoom;
-        scaledCAX = int(float(cax) / (float(zoom)/10.f));
-        scaledCAY = int(float(cay) / (float(zoom)/10.f));
+        wwImgSpace = int(float(ww) * (float(zoom) / 10.f) + 0.5f);
+        whImgSpace = int(float(wh) * (float(zoom) / 10.f) + 0.5f);
+        // scaledFullW = fullW / zoom;
+        // scaledFullH = fullH / zoom;
+        scaledCAX = int(float(cax) / (float(zoom) / 10.f));
+        scaledCAY = int(float(cay) / (float(zoom) / 10.f));
     }
 
     imgX = ww / 2 - scaledCAX;
@@ -801,8 +790,8 @@ void CropHandler::compDim ()
         imgY = 0;
     }
 
-    cropX = cax - (wwImgSpace/2);
-    cropY = cay - (whImgSpace/2);
+    cropX = cax - (wwImgSpace / 2);
+    cropY = cay - (whImgSpace / 2);
     cropW = wwImgSpace;
     cropH = whImgSpace;
 
