@@ -18,32 +18,29 @@
  */
 #include "exifpanel.h"
 
-#include "guiutils.h"
-#include "rtimage.h"
 #include "../rtengine/imagedata.h"
 #include "../rtengine/metadata.h"
+#include "guiutils.h"
+#include "rtimage.h"
 
 #include <glibmm/regex.h>
 
 using namespace rtengine;
 using namespace rtengine::procparams;
 
-
-ExifPanel::ExifPanel():
-    idata(nullptr),
-    pl_(nullptr)
+ExifPanel::ExifPanel(): idata(nullptr), pl_(nullptr)
 {
     for (auto &k : MetaDataParams::basicExifKeys) {
         editable_.push_back(std::make_pair(k, ""));
     }
-    
-    exifTree = Gtk::manage (new Gtk::TreeView());
-    scrolledWindow = Gtk::manage (new Gtk::ScrolledWindow());
 
-    exifTree->set_headers_visible (false);
-    exifTree->set_rules_hint (false);
-    exifTree->set_reorderable (false);
-    exifTree->set_enable_search (true);
+    exifTree = Gtk::manage(new Gtk::TreeView());
+    scrolledWindow = Gtk::manage(new Gtk::ScrolledWindow());
+
+    exifTree->set_headers_visible(false);
+    exifTree->set_rules_hint(false);
+    exifTree->set_reorderable(false);
+    exifTree->set_enable_search(true);
     exifTree->get_selection()->set_mode(Gtk::SELECTION_SINGLE);
     scrolledWindow->set_shadow_type(Gtk::SHADOW_NONE);
     scrolledWindow->set_policy(Gtk::POLICY_ALWAYS, Gtk::POLICY_ALWAYS);
@@ -57,22 +54,27 @@ ExifPanel::ExifPanel():
     exifTree->set_tooltip_column(10);
     exifTree->set_enable_search(false);
     exifTree->set_search_column(0);
-        
-    //keepicon = RTImage::createPixbufFromFile("tick-small.svg");
+
+    // keepicon = RTImage::createPixbufFromFile("tick-small.svg");
     editicon = RTImage::createPixbufFromFile("edit-small.svg");
     open_icon_ = RTImage::createPixbufFromFile("expander-open-small.svg");
     closed_icon_ = RTImage::createPixbufFromFile("expander-closed-small.svg");
 
     exif_active_renderer_.property_mode() = Gtk::CELL_RENDERER_MODE_ACTIVATABLE;
-    exif_active_renderer_.signal_toggled().connect(sigc::mem_fun(this, &ExifPanel::onKeyActiveToggled));
+    exif_active_renderer_.signal_toggled().connect(
+        sigc::mem_fun(this, &ExifPanel::onKeyActiveToggled));
     exif_active_column_.pack_start(exif_active_renderer_);
-    exif_active_column_.set_cell_data_func(exif_active_renderer_, sigc::mem_fun(this, &ExifPanel::setKeyActive));
-    
+    exif_active_column_.set_cell_data_func(
+        exif_active_renderer_, sigc::mem_fun(this, &ExifPanel::setKeyActive));
+
     exifTree->append_column(exif_active_column_);
-    
-    Gtk::TreeView::Column *viewcol = Gtk::manage (new Gtk::TreeView::Column ("Field Name"));
-    Gtk::CellRendererPixbuf* render_pb = Gtk::manage (new Gtk::CellRendererPixbuf ());
-    Gtk::CellRendererText *render_txt = Gtk::manage (new Gtk::CellRendererText());
+
+    Gtk::TreeView::Column *viewcol =
+        Gtk::manage(new Gtk::TreeView::Column("Field Name"));
+    Gtk::CellRendererPixbuf *render_pb =
+        Gtk::manage(new Gtk::CellRendererPixbuf());
+    Gtk::CellRendererText *render_txt =
+        Gtk::manage(new Gtk::CellRendererText());
     render_txt->property_ellipsize() = Pango::ELLIPSIZE_END;
     viewcol->pack_start(*render_pb, false);
     viewcol->pack_start(*render_txt, true);
@@ -90,82 +92,96 @@ ExifPanel::ExifPanel():
     render_txt->property_yalign() = 0;
 
     exifTree->append_column(*viewcol);
-    //exifTree->set_expander_column(*viewcol);
+    // exifTree->set_expander_column(*viewcol);
 
-    Gtk::TreeView::Column *viewcolv = Gtk::manage(new Gtk::TreeView::Column ("Value"));
-    Gtk::CellRendererText *render_txtv = Gtk::manage(new Gtk::CellRendererText());
+    Gtk::TreeView::Column *viewcolv =
+        Gtk::manage(new Gtk::TreeView::Column("Value"));
+    Gtk::CellRendererText *render_txtv =
+        Gtk::manage(new Gtk::CellRendererText());
     render_txtv->property_ellipsize() = Pango::ELLIPSIZE_END;
-    viewcolv->pack_start (*render_txtv, true);
+    viewcolv->pack_start(*render_txtv, true);
     // viewcolv->add_attribute (*render_txtv, "markup", exifColumns.value);
-    viewcolv->set_expand (true);
-    viewcolv->set_resizable (true);
-    viewcol->set_fixed_width (35);
-    viewcolv->set_min_width (35);
-    viewcolv->set_sizing (Gtk::TREE_VIEW_COLUMN_AUTOSIZE);
+    viewcolv->set_expand(true);
+    viewcolv->set_resizable(true);
+    viewcol->set_fixed_width(35);
+    viewcolv->set_min_width(35);
+    viewcolv->set_sizing(Gtk::TREE_VIEW_COLUMN_AUTOSIZE);
 
     render_txtv->property_ypad() = 0;
-    viewcolv->set_cell_data_func(*render_txtv, sigc::mem_fun(this, &ExifPanel::setExifTagValue));
-    render_txtv->signal_edited().connect(sigc::mem_fun(this, &ExifPanel::onEditExifTagValue));
+    viewcolv->set_cell_data_func(
+        *render_txtv, sigc::mem_fun(this, &ExifPanel::setExifTagValue));
+    render_txtv->signal_edited().connect(
+        sigc::mem_fun(this, &ExifPanel::onEditExifTagValue));
 
     exifTree->append_column(*viewcolv);
 
-    pack_start (*scrolledWindow);
+    pack_start(*scrolledWindow);
 
-    Gtk::Grid* buttons1 = Gtk::manage (new Gtk::Grid());
-    buttons1->set_row_homogeneous (true);
-    buttons1->set_column_homogeneous (true);
-    setExpandAlignProperties (buttons1, true, false, Gtk::ALIGN_FILL, Gtk::ALIGN_CENTER);
+    Gtk::Grid *buttons1 = Gtk::manage(new Gtk::Grid());
+    buttons1->set_row_homogeneous(true);
+    buttons1->set_column_homogeneous(true);
+    setExpandAlignProperties(buttons1, true, false, Gtk::ALIGN_FILL,
+                             Gtk::ALIGN_CENTER);
 
-    const auto addbtn =
-        [&](const char *cssclass, const Glib::ustring &tip, const Glib::ustring &icon1, const Glib::ustring &icon2=Glib::ustring()) -> Gtk::Button *
-        {
-            Gtk::Button *b = Gtk::manage(new Gtk::Button());
-            b->set_image(*Gtk::manage(new RTImage(icon1, icon2)));
-            b->set_tooltip_text(M(tip));
-            b->get_style_context()->add_class(cssclass);
-            setExpandAlignProperties(b, true, true, Gtk::ALIGN_FILL, Gtk::ALIGN_FILL);
-            buttons1->attach_next_to(*b, Gtk::POS_RIGHT, 1, 1);
-            return b;
-        };
+    const auto addbtn = [&](const char *cssclass, const Glib::ustring &tip,
+                            const Glib::ustring &icon1,
+                            const Glib::ustring &icon2 =
+                                Glib::ustring()) -> Gtk::Button * {
+        Gtk::Button *b = Gtk::manage(new Gtk::Button());
+        b->set_image(*Gtk::manage(new RTImage(icon1, icon2)));
+        b->set_tooltip_text(M(tip));
+        b->get_style_context()->add_class(cssclass);
+        setExpandAlignProperties(b, true, true, Gtk::ALIGN_FILL,
+                                 Gtk::ALIGN_FILL);
+        buttons1->attach_next_to(*b, Gtk::POS_RIGHT, 1, 1);
+        return b;
+    };
 
     activate_all_ = addbtn("Left", "EXIFPANEL_ACTIVATE_ALL_HINT", "tick.svg");
-    activate_none_ = addbtn("MiddleH", "EXIFPANEL_ACTIVATE_NONE_HINT", "box.svg");
+    activate_none_ =
+        addbtn("MiddleH", "EXIFPANEL_ACTIVATE_NONE_HINT", "box.svg");
     add = addbtn("MiddleH", "EXIFPANEL_ADDEDIT", "edit.svg");
     reset = addbtn("MiddleH", "EXIFPANEL_RESETHINT", "undo.svg", "redo.svg");
-    resetAll = addbtn("Right", "EXIFPANEL_RESETALLHINT", "undo-all.svg", "redo-all.svg");
+    resetAll = addbtn("Right", "EXIFPANEL_RESETALLHINT", "undo-all.svg",
+                      "redo-all.svg");
 
-    pack_end (*buttons1, Gtk::PACK_SHRINK);
+    pack_end(*buttons1, Gtk::PACK_SHRINK);
 
-    exifTree->get_selection()->signal_changed().connect (sigc::mem_fun (*this, &ExifPanel::exifSelectionChanged));
+    exifTree->get_selection()->signal_changed().connect(
+        sigc::mem_fun(*this, &ExifPanel::exifSelectionChanged));
 
-    reset->signal_clicked().connect ( sigc::mem_fun (*this, &ExifPanel::resetPressed) );
-    resetAll->signal_clicked().connect ( sigc::mem_fun (*this, &ExifPanel::resetAllPressed) );
-    add->signal_clicked().connect ( sigc::mem_fun (*this, &ExifPanel::addPressed) );
-    activate_all_->signal_clicked().connect(sigc::mem_fun(*this, &ExifPanel::activateAllPressed));
-    activate_none_->signal_clicked().connect(sigc::mem_fun(*this, &ExifPanel::activateNonePressed));
+    reset->signal_clicked().connect(
+        sigc::mem_fun(*this, &ExifPanel::resetPressed));
+    resetAll->signal_clicked().connect(
+        sigc::mem_fun(*this, &ExifPanel::resetAllPressed));
+    add->signal_clicked().connect(sigc::mem_fun(*this, &ExifPanel::addPressed));
+    activate_all_->signal_clicked().connect(
+        sigc::mem_fun(*this, &ExifPanel::activateAllPressed));
+    activate_none_->signal_clicked().connect(
+        sigc::mem_fun(*this, &ExifPanel::activateNonePressed));
 
-    exifTree->signal_button_press_event().connect_notify(sigc::mem_fun(*this, &ExifPanel::onExifTreeClick));
-    exifTree->signal_row_expanded().connect(sigc::mem_fun(*this, &ExifPanel::onExifRowExpanded));
-    exifTree->signal_row_collapsed().connect(sigc::mem_fun(*this, &ExifPanel::onExifRowCollapsed));
+    exifTree->signal_button_press_event().connect_notify(
+        sigc::mem_fun(*this, &ExifPanel::onExifTreeClick));
+    exifTree->signal_row_expanded().connect(
+        sigc::mem_fun(*this, &ExifPanel::onExifRowExpanded));
+    exifTree->signal_row_collapsed().connect(
+        sigc::mem_fun(*this, &ExifPanel::onExifRowCollapsed));
 
     setTreeViewCssProvider(exifTree);
 
-    show_all ();
+    show_all();
 }
 
+ExifPanel::~ExifPanel() {}
 
-ExifPanel::~ExifPanel ()
-{
-}
-
-
-void ExifPanel::read(const ProcParams* pp)
+void ExifPanel::read(const ProcParams *pp)
 {
     disableListener();
 
     changeList = pp->metadata.exif;
     initial_active_keys_.clear();
-    initial_active_keys_.insert(pp->metadata.exifKeys.begin(), pp->metadata.exifKeys.end());
+    initial_active_keys_.insert(pp->metadata.exifKeys.begin(),
+                                pp->metadata.exifKeys.end());
     cur_active_keys_ = initial_active_keys_;
     setImageData(idata);
     refreshTags();
@@ -173,56 +189,52 @@ void ExifPanel::read(const ProcParams* pp)
     enableListener();
 }
 
-
-void ExifPanel::write(ProcParams* pp)
+void ExifPanel::write(ProcParams *pp)
 {
     pp->metadata.exif = changeList;
     cur_active_keys_ = get_active_keys();
-    pp->metadata.exifKeys.assign(cur_active_keys_.begin(), cur_active_keys_.end());
+    pp->metadata.exifKeys.assign(cur_active_keys_.begin(),
+                                 cur_active_keys_.end());
     std::sort(pp->metadata.exifKeys.begin(), pp->metadata.exifKeys.end());
 }
 
-
-void ExifPanel::setDefaults(const ProcParams* defParams)
+void ExifPanel::setDefaults(const ProcParams *defParams)
 {
     defChangeList = defParams->metadata.exif;
 }
 
+void ExifPanel::setImageData(const FramesMetaData *id) { idata = id; }
 
-void ExifPanel::setImageData (const FramesMetaData* id)
-{
-    idata = id;
-}
-
-
-void ExifPanel::addTag(const std::string &key, const std::pair<Glib::ustring, Glib::ustring> &label, const Glib::ustring &value, bool editable, bool edited, bool activatable)
+void ExifPanel::addTag(const std::string &key,
+                       const std::pair<Glib::ustring, Glib::ustring> &label,
+                       const Glib::ustring &value, bool editable, bool edited,
+                       bool activatable)
 {
     const auto getgroup =
-        [&]() -> std::pair<Glib::ustring, Gtk::TreeNodeChildren>
-        {
-            auto root = exifTreeModel->children();
-            
-            for (auto &row : root) {
-                std::string key = row[exifColumns.key];
-                if (row[exifColumns.is_group] && key == label.first) {
-                    return std::make_pair(key, row.children());
-                }
-            }
-            auto it = exifTreeModel->append(root);
-            auto row = *it;
-            
-            row[exifColumns.editable] = false;
-            row[exifColumns.edited] = false;
-            row[exifColumns.key] = label.first;
-            row[exifColumns.label] = "<b>" + label.first + "</b>";
-            row[exifColumns.value_nopango] = "";
-            row[exifColumns.value] = "";
-            row[exifColumns.is_group] = true;
-            row[exifColumns.activatable] = activatable;
-            row[exifColumns.tooltip] = label.first;
+        [&]() -> std::pair<Glib::ustring, Gtk::TreeNodeChildren> {
+        auto root = exifTreeModel->children();
 
-            return std::make_pair(label.first, it->children());
-        };
+        for (auto &row : root) {
+            std::string key = row[exifColumns.key];
+            if (row[exifColumns.is_group] && key == label.first) {
+                return std::make_pair(key, row.children());
+            }
+        }
+        auto it = exifTreeModel->append(root);
+        auto row = *it;
+
+        row[exifColumns.editable] = false;
+        row[exifColumns.edited] = false;
+        row[exifColumns.key] = label.first;
+        row[exifColumns.label] = "<b>" + label.first + "</b>";
+        row[exifColumns.value_nopango] = "";
+        row[exifColumns.value] = "";
+        row[exifColumns.is_group] = true;
+        row[exifColumns.activatable] = activatable;
+        row[exifColumns.tooltip] = label.first;
+
+        return std::make_pair(label.first, it->children());
+    };
 
     auto p = getgroup();
     auto root = p.second;
@@ -238,24 +250,26 @@ void ExifPanel::addTag(const std::string &key, const std::pair<Glib::ustring, Gl
     row[exifColumns.label] = lbl;
     row[exifColumns.value] = value;
 
-    bool active = activatable && (all_keys_active() || cur_active_keys_.find(key) != cur_active_keys_.end());
+    bool active =
+        activatable && (all_keys_active() ||
+                        cur_active_keys_.find(key) != cur_active_keys_.end());
     row[exifColumns.active] = active;
     row[exifColumns.activatable] = activatable;
 
     if (edited) {
         row[exifColumns.icon] = editicon;
     }
-    row[exifColumns.tooltip] = Glib::ustring::compose(M("EXIFPANEL_METADATUM_TOOLTIP"), p.first + " ► " + lbl, key, value);
+    row[exifColumns.tooltip] = Glib::ustring::compose(
+        M("EXIFPANEL_METADATUM_TOOLTIP"), p.first + " ► " + lbl, key, value);
 }
 
-
 void ExifPanel::refreshTags()
 {
     Glib::RefPtr<Gtk::TreeSelection> selection = exifTree->get_selection();
     std::vector<Gtk::TreeModel::Path> sel = selection->get_selected_rows();
-    
+
     exifTreeModel->clear();
-    
+
     if (!idata) {
         return;
     }
@@ -271,61 +285,64 @@ void ExifPanel::refreshTags()
     }
 
     const auto to_label =
-        [](Exiv2::Exifdatum &tag) -> std::pair<Glib::ustring, Glib::ustring>
-        {
-            auto s = tag.key();
-            auto pos = s.find('.');
-            if (pos != std::string::npos) {
-                s = s.substr(pos+1);
-            }
-            Glib::ustring g = "";
-            pos = s.find('.');
-            if (pos != std::string::npos) {
-                g = s.substr(0, pos);
-                s = s.substr(pos+1);
-            }
-            auto l = tag.tagLabel();
-            if (!l.empty()) {
-                s = l;
-            }
-            return std::make_pair(g, Glib::ustring(s));
-        };
+        [](Exiv2::Exifdatum &tag) -> std::pair<Glib::ustring, Glib::ustring> {
+        auto s = tag.key();
+        auto pos = s.find('.');
+        if (pos != std::string::npos) {
+            s = s.substr(pos + 1);
+        }
+        Glib::ustring g = "";
+        pos = s.find('.');
+        if (pos != std::string::npos) {
+            g = s.substr(0, pos);
+            s = s.substr(pos + 1);
+        }
+        auto l = tag.tagLabel();
+        if (!l.empty()) {
+            s = l;
+        }
+        return std::make_pair(g, Glib::ustring(s));
+    };
 
     try {
         rtengine::Exiv2Metadata meta(fn);
         meta.load();
         Exiv2::ExifData exif = meta.exifData();
 
-        const auto to_value =
-            [&](Exiv2::Exifdatum &tag) -> Glib::ustring
-            {
-                try {
-                    if (!tag.tagLabel().empty() && (tag.typeId() == Exiv2::asciiString || tag.size() < 256)) {
-                        auto ret = escapeHtmlChars(tag.print(&exif));
-                        if (!ret.validate()) {
-                            return "<i>(" + M("EXIFPANEL_VALUE_NOT_SHOWN") + ")</i>";
-                        }
-                        return ret;
+        const auto to_value = [&](Exiv2::Exifdatum &tag) -> Glib::ustring {
+            try {
+                if (!tag.tagLabel().empty() &&
+                    (tag.typeId() == Exiv2::asciiString || tag.size() < 256)) {
+                    auto ret = escapeHtmlChars(tag.print(&exif));
+                    if (!ret.validate()) {
+                        return "<i>(" + M("EXIFPANEL_VALUE_NOT_SHOWN") +
+                               ")</i>";
                     }
-                } catch (std::exception &) {}
-                return "<i>(" + M("EXIFPANEL_VALUE_NOT_SHOWN") + ")</i>";
-            };
+                    return ret;
+                }
+            } catch (std::exception &) {
+            }
+            return "<i>(" + M("EXIFPANEL_VALUE_NOT_SHOWN") + ")</i>";
+        };
 
-        if (const rtengine::FramesData *fd = dynamic_cast<const rtengine::FramesData *>(idata)) {
+        if (const rtengine::FramesData *fd =
+                dynamic_cast<const rtengine::FramesData *>(idata)) {
             fd->fillBasicTags(exif);
         }
-        
+
         for (auto &p : changeList) {
             try {
                 auto &datum = exif[p.first];
                 if (datum.setValue(p.second) != 0) {
                     if (pl_) {
-                        pl_->error(Glib::ustring::compose(M("ERROR_MSG_METADATA_VALUE"), p.first, p.second));
+                        pl_->error(Glib::ustring::compose(
+                            M("ERROR_MSG_METADATA_VALUE"), p.first, p.second));
                     }
-                }                
+                }
             } catch (std::exception &exc) {
                 if (pl_) {
-                    pl_->error(Glib::ustring::compose(M("ERROR_MSG_METADATA_VALUE"), p.first, p.second));
+                    pl_->error(Glib::ustring::compose(
+                        M("ERROR_MSG_METADATA_VALUE"), p.first, p.second));
                 }
             }
         }
@@ -347,13 +364,11 @@ void ExifPanel::refreshTags()
             addTag(p.first, lbl, value, true, edited);
         }
         struct KeyLt {
-            KeyLt():
-                order_{
-                    {"Exif.GPSInfo", 0},
-                    {"Exif.Photo", 1},
-                    {"Exif.Image", 2}
-                }
-            {}
+            KeyLt()
+                : order_{
+                      {"Exif.GPSInfo", 0}, {"Exif.Photo", 1}, {"Exif.Image", 2}}
+            {
+            }
             bool operator()(const std::string &a, const std::string &b) const
             {
                 auto p1 = a.find_last_of('.');
@@ -361,15 +376,15 @@ void ExifPanel::refreshTags()
                 const char *sa = a.c_str();
                 const char *sb = b.c_str();
                 if (p1 != std::string::npos && p2 != std::string::npos) {
-                    bool hex_a = strncmp(sa+p1+1, "0x", 2) == 0;
-                    bool hex_b = strncmp(sb+p2+1, "0x", 2) == 0;
+                    bool hex_a = strncmp(sa + p1 + 1, "0x", 2) == 0;
+                    bool hex_b = strncmp(sb + p2 + 1, "0x", 2) == 0;
                     if (hex_a != hex_b) {
                         return !hex_a;
                     }
                 }
                 if (p1 != p2 || strncmp(sa, sb, p1) != 0) {
-                    std::string ga(sa, sa+p1);
-                    std::string gb(sb, sb+p2);
+                    std::string ga(sa, sa + p1);
+                    std::string gb(sb, sb + p2);
                     int ia = getorder(ga);
                     int ib = getorder(gb);
                     if (ia != ib) {
@@ -411,7 +426,10 @@ void ExifPanel::refreshTags()
                 if (!val.validate()) {
                     val = "<i>(" + M("EXIFPANEL_VALUE_NOT_SHOWN") + ")</i>";
                 }
-                addTag(key, std::pair<Glib::ustring, Glib::ustring>("ExifTool MakerNotes", p.first), val, false, false, false);
+                addTag(key,
+                       std::pair<Glib::ustring, Glib::ustring>(
+                           "ExifTool MakerNotes", p.first),
+                       val, false, false, false);
             }
         }
     } catch (std::exception &exc) {
@@ -425,14 +443,13 @@ void ExifPanel::refreshTags()
     exifTree->expand_all();
 }
 
-
-void ExifPanel::exifSelectionChanged ()
+void ExifPanel::exifSelectionChanged()
 {
     Glib::RefPtr<Gtk::TreeSelection> selection = exifTree->get_selection();
     std::vector<Gtk::TreeModel::Path> sel = selection->get_selected_rows();
 
     if (sel.size() >= 1) {
-        Gtk::TreeModel::iterator iter = exifTreeModel->get_iter (sel[0]);
+        Gtk::TreeModel::iterator iter = exifTreeModel->get_iter(sel[0]);
         if (iter->get_value(exifColumns.editable)) {
             reset->set_sensitive(true);
             add->set_sensitive(true);
@@ -443,8 +460,7 @@ void ExifPanel::exifSelectionChanged ()
     }
 }
 
-
-void ExifPanel::resetIt (Gtk::TreeModel::iterator  iter)
+void ExifPanel::resetIt(Gtk::TreeModel::iterator iter)
 {
     if (!iter) {
         return;
@@ -454,7 +470,6 @@ void ExifPanel::resetIt (Gtk::TreeModel::iterator  iter)
     changeList.erase(key);
 }
 
-
 void ExifPanel::resetPressed()
 {
     cur_active_keys_ = get_active_keys();
@@ -469,11 +484,10 @@ void ExifPanel::resetPressed()
     if (!sel.empty()) {
         exifTree->get_selection()->select(sel[0]);
     }
-        
+
     notifyListener();
 }
 
-
 void ExifPanel::resetAllPressed()
 {
     auto sel = exifTree->get_selection()->get_selected_rows();
@@ -487,7 +501,6 @@ void ExifPanel::resetAllPressed()
     notifyListener();
 }
 
-
 void ExifPanel::addPressed()
 {
     Gtk::TreeModel::Path path;
@@ -500,7 +513,6 @@ void ExifPanel::addPressed()
     }
 }
 
-
 void ExifPanel::activateAllPressed()
 {
     disableListener();
@@ -519,7 +531,6 @@ void ExifPanel::activateAllPressed()
     notifyListener();
 }
 
-
 void ExifPanel::activateNonePressed()
 {
     disableListener();
@@ -534,7 +545,6 @@ void ExifPanel::activateNonePressed()
     notifyListener();
 }
 
-
 void ExifPanel::notifyListener()
 {
     if (listener) {
@@ -542,7 +552,6 @@ void ExifPanel::notifyListener()
     }
 }
 
-
 void ExifPanel::onKeyActiveToggled(const Glib::ustring &path)
 {
     auto it = exifTreeModel->get_iter(path);
@@ -561,11 +570,12 @@ void ExifPanel::onKeyActiveToggled(const Glib::ustring &path)
     }
 }
 
-
-void ExifPanel::setKeyActive(Gtk::CellRenderer *renderer, const Gtk::TreeModel::iterator &it)
+void ExifPanel::setKeyActive(Gtk::CellRenderer *renderer,
+                             const Gtk::TreeModel::iterator &it)
 {
     auto row = *it;
-    Gtk::CellRendererToggle *toggle = static_cast<Gtk::CellRendererToggle *>(renderer);
+    Gtk::CellRendererToggle *toggle =
+        static_cast<Gtk::CellRendererToggle *>(renderer);
     if (row[exifColumns.is_group]) {
         bool all_true = true, all_false = true;
         for (auto &c : row.children()) {
@@ -587,13 +597,11 @@ void ExifPanel::setKeyActive(Gtk::CellRenderer *renderer, const Gtk::TreeModel::
     }
 }
 
-
 bool ExifPanel::all_keys_active() const
 {
     return (cur_active_keys_.size() == 1 && *(cur_active_keys_.begin()) == "*");
 }
 
-
 std::unordered_set<std::string> ExifPanel::get_active_keys() const
 {
     bool all_active = true;
@@ -619,12 +627,14 @@ std::unordered_set<std::string> ExifPanel::get_active_keys() const
 }
 
 void ExifPanel::onExifTreeClick(GdkEventButton *event)
-{    
+{
     Gtk::TreeModel::Path pth;
     Gtk::TreeViewColumn *col;
     int cell_x;
     int cell_y;
-    if (exifTree->get_path_at_pos(event->x, event->y, pth, col, cell_x, cell_y) && col == exifTree->get_column(1) && cell_x <= 22) {
+    if (exifTree->get_path_at_pos(event->x, event->y, pth, col, cell_x,
+                                  cell_y) &&
+        col == exifTree->get_column(1) && cell_x <= 22) {
         auto it = exifTreeModel->get_iter(pth);
         auto row = *it;
         if (row[exifColumns.is_group]) {
@@ -637,8 +647,8 @@ void ExifPanel::onExifTreeClick(GdkEventButton *event)
     }
 }
 
-
-void ExifPanel::onExifRowExpanded(const Gtk::TreeModel::iterator &it, const Gtk::TreeModel::Path &path)
+void ExifPanel::onExifRowExpanded(const Gtk::TreeModel::iterator &it,
+                                  const Gtk::TreeModel::Path &path)
 {
     auto row = *it;
     if (row[exifColumns.is_group]) {
@@ -646,8 +656,8 @@ void ExifPanel::onExifRowExpanded(const Gtk::TreeModel::iterator &it, const Gtk:
     }
 }
 
-
-void ExifPanel::onExifRowCollapsed(const Gtk::TreeModel::iterator &it, const Gtk::TreeModel::Path &path)
+void ExifPanel::onExifRowCollapsed(const Gtk::TreeModel::iterator &it,
+                                   const Gtk::TreeModel::Path &path)
 {
     auto row = *it;
     if (row[exifColumns.is_group]) {
@@ -655,8 +665,8 @@ void ExifPanel::onExifRowCollapsed(const Gtk::TreeModel::iterator &it, const Gtk
     }
 }
 
-
-void ExifPanel::setExifTagValue(Gtk::CellRenderer *renderer, const Gtk::TreeModel::iterator &it)
+void ExifPanel::setExifTagValue(Gtk::CellRenderer *renderer,
+                                const Gtk::TreeModel::iterator &it)
 {
     auto row = *it;
     Gtk::CellRendererText *txt = static_cast<Gtk::CellRendererText *>(renderer);
@@ -664,7 +674,6 @@ void ExifPanel::setExifTagValue(Gtk::CellRenderer *renderer, const Gtk::TreeMode
     txt->property_markup() = row[exifColumns.value];
 }
 
-
 namespace {
 
 class InvalidValue: public std::exception {};
@@ -673,7 +682,8 @@ Glib::ustring to_fraction(const Glib::ustring &s)
 {
     auto i = s.find('.');
     if (i != Glib::ustring::npos) {
-        return s.substr(0, i) + s.substr(i+1) + "/1" + Glib::ustring(s.size() - i - 1, '0');
+        return s.substr(0, i) + s.substr(i + 1) + "/1" +
+               Glib::ustring(s.size() - i - 1, '0');
     } else if (s.find('/') == Glib::ustring::npos) {
         return s + "/1";
     }
@@ -711,7 +721,8 @@ Glib::ustring get_shutterspeed(const Glib::ustring &val)
 Glib::ustring get_focallen(const Glib::ustring &val)
 {
     Glib::MatchInfo m;
-    auto re = Glib::Regex::create("^ *([0-9.]+) *(mm)? *$", Glib::REGEX_CASELESS);
+    auto re =
+        Glib::Regex::create("^ *([0-9.]+) *(mm)? *$", Glib::REGEX_CASELESS);
     if (re->match(val, m)) {
         auto s = m.fetch(1);
         return to_fraction(s);
@@ -724,7 +735,8 @@ Glib::ustring get_focallen(const Glib::ustring &val)
 Glib::ustring get_expcomp(const Glib::ustring &val)
 {
     Glib::MatchInfo m;
-    auto re = Glib::Regex::create("^ *(-?[0-9.]+) *(EV)? *$", Glib::REGEX_CASELESS);
+    auto re =
+        Glib::Regex::create("^ *(-?[0-9.]+) *(EV)? *$", Glib::REGEX_CASELESS);
     if (re->match(val, m)) {
         auto s = m.fetch(1);
         return to_fraction(s);
@@ -738,13 +750,12 @@ std::unordered_map<std::string, validator_func> validators = {
     {"Exif.Photo.FNumber", get_fnumber},
     {"Exif.Photo.ExposureTime", get_shutterspeed},
     {"Exif.Photo.FocalLength", get_focallen},
-    {"Exif.Photo.ExposureBiasValue", get_expcomp}
-};
+    {"Exif.Photo.ExposureBiasValue", get_expcomp}};
 
 } // namespace
 
-
-void ExifPanel::onEditExifTagValue(const Glib::ustring &path, const Glib::ustring &val)
+void ExifPanel::onEditExifTagValue(const Glib::ustring &path,
+                                   const Glib::ustring &val)
 {
     auto it = exifTreeModel->get_iter(path);
     auto row = *it;
@@ -763,7 +774,9 @@ void ExifPanel::onEditExifTagValue(const Glib::ustring &path, const Glib::ustrin
             }
         }
         if (datum.setValue(value) != 0) {
-            if ((datum.typeId() == Exiv2::signedRational || datum.typeId() == Exiv2::unsignedRational) && datum.setValue(value + "/1") == 0) {
+            if ((datum.typeId() == Exiv2::signedRational ||
+                 datum.typeId() == Exiv2::unsignedRational) &&
+                datum.setValue(value + "/1") == 0) {
                 value += "/1";
             } else {
                 good = false;
@@ -779,16 +792,16 @@ void ExifPanel::onEditExifTagValue(const Glib::ustring &path, const Glib::ustrin
             cur_active_keys_.insert(key);
         }
         refreshTags();
-    
+
         it = exifTreeModel->get_iter(path);
         exifTree->get_selection()->select(it);
         notifyListener();
     } else if (pl_) {
-        pl_->error(Glib::ustring::compose(M("ERROR_MSG_METADATA_VALUE"), key, value));
+        pl_->error(
+            Glib::ustring::compose(M("ERROR_MSG_METADATA_VALUE"), key, value));
     }
 }
 
-
 void ExifPanel::setProgressListener(rtengine::ProgressListener *pl)
 {
     pl_ = pl;
