@@ -1,5 +1,5 @@
 /* -*- C++ -*-
- *  
+ *
  *  This file is part of RawTherapee.
  *
  *  Copyright (c) 2004-2010 Gabor Horvath <hgabor@rawtherapee.com>
@@ -25,12 +25,8 @@ class BatchQueueEntry;
 class FileSelectionListener {
 public:
     virtual ~FileSelectionListener() = default;
-    enum Result {
-        FAIL,
-        OK,
-        BUSY
-    };
-    virtual Result fileSelected(Thumbnail* thm) = 0;
-    virtual bool addBatchQueueJobs(const std::vector<BatchQueueEntry*>& entries) = 0;
+    enum Result { FAIL, OK, BUSY };
+    virtual Result fileSelected(Thumbnail *thm) = 0;
+    virtual bool
+    addBatchQueueJobs(const std::vector<BatchQueueEntry *> &entries) = 0;
 };
-
