@@ -1,5 +1,5 @@
 /** -*- C++ -*-
- *  
+ *
  *  This file is part of RawTherapee.
  *
  *  Copyright (c) 2017 Alberto Griggio <alberto.griggio@gmail.com>
@@ -19,8 +19,8 @@
  */
 #include "localcontrast.h"
 #include "eventmapper.h"
-#include <iomanip>
 #include <cmath>
+#include <iomanip>
 
 using namespace rtengine;
 using namespace rtengine::procparams;
@@ -31,20 +31,11 @@ using namespace rtengine::procparams;
 
 class LocalContrastMasksContentProvider: public MasksContentProvider {
 public:
-    LocalContrastMasksContentProvider(LocalContrast *parent):
-        parent_(parent)
-    {
-    }
+    LocalContrastMasksContentProvider(LocalContrast *parent): parent_(parent) {}
 
-    Glib::ustring getToolName() override
-    {
-        return "localcontrast";
-    }
+    Glib::ustring getToolName() override { return "localcontrast"; }
 
-    Gtk::Container *getContainer() override
-    {
-        return parent_->box;
-    }
+    Gtk::Container *getContainer() override { return parent_->box; }
 
     void getEvents(Events &events) override
     {
@@ -72,19 +63,14 @@ public:
         return nullptr;
     }
 
-    void selectionChanging(int idx) override
-    {
-        parent_->regionGet(idx);
-    }
+    void selectionChanging(int idx) override { parent_->regionGet(idx); }
 
-    void selectionChanged(int idx) override
-    {
-        parent_->regionShow(idx);
-    }
+    void selectionChanged(int idx) override { parent_->regionShow(idx); }
 
     bool addPressed(int idx) override
     {
-        parent_->regionData.insert(parent_->regionData.begin() + idx, LocalContrastParams::Region());
+        parent_->regionData.insert(parent_->regionData.begin() + idx,
+                                   LocalContrastParams::Region());
         return true;
     }
 
@@ -93,20 +79,21 @@ public:
         parent_->regionData.erase(parent_->regionData.begin() + idx);
         return true;
     }
-    
+
     bool copyPressed(int idx) override
     {
-        parent_->regionData.insert(parent_->regionData.begin() + idx + 1, parent_->regionData[idx]);
+        parent_->regionData.insert(parent_->regionData.begin() + idx + 1,
+                                   parent_->regionData[idx]);
         return true;
     }
 
     bool resetPressed(int idx) override
     {
         parent_->regionData[idx] = LocalContrastParams::Region();
-        //parent_->masks_->setMasks({ Mask() }, -1);
+        // parent_->masks_->setMasks({ Mask() }, -1);
         return true;
     }
-    
+
     bool moveUpPressed(int idx) override
     {
         auto r = parent_->regionData[idx];
@@ -115,7 +102,7 @@ public:
         parent_->regionData.insert(parent_->regionData.begin() + idx, r);
         return true;
     }
-    
+
     bool moveDownPressed(int idx) override
     {
         auto r = parent_->regionData[idx];
@@ -125,16 +112,13 @@ public:
         return true;
     }
 
-    int getColumnCount() override
-    {
-        return 1;
-    }
-    
+    int getColumnCount() override { return 1; }
+
     Glib::ustring getColumnHeader(int col) override
     {
         return M("TP_LABMASKS_PARAMETERS");
     }
-    
+
     Glib::ustring getColumnContent(int col, int row) override
     {
         auto &r = parent_->regionData[row];
@@ -143,12 +127,10 @@ public:
         if (r.curve.size() > 1) {
             std::ostringstream buf;
             const char *sep = "";
-            for (size_t i = 1; i+3 < r.curve.size();  i += 4) {
-                buf << sep << "("
-                    << std::fixed << std::setprecision(2) << r.curve[i]
-                    << ", "
-                    << std::fixed << std::setprecision(2) << r.curve[i+1]
-                    << ")";
+            for (size_t i = 1; i + 3 < r.curve.size(); i += 4) {
+                buf << sep << "(" << std::fixed << std::setprecision(2)
+                    << r.curve[i] << ", " << std::fixed << std::setprecision(2)
+                    << r.curve[i + 1] << ")";
                 sep = " ";
             }
             c = buf.str();
@@ -156,7 +138,8 @@ public:
         return Glib::ustring::compose("%1\n[%2]", c, r.contrast);
     }
 
-    void getEditIDs(EditUniqueID &hcurve, EditUniqueID &ccurve, EditUniqueID &lcurve, EditUniqueID &deltaE) override
+    void getEditIDs(EditUniqueID &hcurve, EditUniqueID &ccurve,
+                    EditUniqueID &lcurve, EditUniqueID &deltaE) override
     {
         hcurve = EUID_Masks_H2;
         ccurve = EUID_Masks_C2;
@@ -168,51 +151,65 @@ private:
     LocalContrast *parent_;
 };
 
-
 //-----------------------------------------------------------------------------
 // LocalContrast
 //-----------------------------------------------------------------------------
 
-LocalContrast::LocalContrast(): FoldableToolPanel(this, "localcontrast", M("TP_LOCALCONTRAST_LABEL"), true, true, true)
+LocalContrast::LocalContrast()
+    : FoldableToolPanel(this, "localcontrast", M("TP_LOCALCONTRAST_LABEL"),
+                        true, true, true)
 {
     auto m = ProcEventMapper::getInstance();
     auto EVENT = rtengine::DISPLAY;
-    EvLocalContrastEnabled = m->newEvent(EVENT, "HISTORY_MSG_LOCALCONTRAST_ENABLED");
-    EvLocalContrastContrast = m->newEvent(EVENT, "HISTORY_MSG_LOCALCONTRAST_CONTRAST");
-    EvLocalContrastCurve = m->newEvent(EVENT, "HISTORY_MSG_LOCALCONTRAST_CURVE");
+    EvLocalContrastEnabled =
+        m->newEvent(EVENT, "HISTORY_MSG_LOCALCONTRAST_ENABLED");
+    EvLocalContrastContrast =
+        m->newEvent(EVENT, "HISTORY_MSG_LOCALCONTRAST_CONTRAST");
+    EvLocalContrastCurve =
+        m->newEvent(EVENT, "HISTORY_MSG_LOCALCONTRAST_CURVE");
 
     EvList = m->newEvent(EVENT, "HISTORY_MSG_LOCALCONTRAST_LIST");
-    EvParametricMask = m->newEvent(EVENT, "HISTORY_MSG_LOCALCONTRAST_PARAMETRICMASK");
+    EvParametricMask =
+        m->newEvent(EVENT, "HISTORY_MSG_LOCALCONTRAST_PARAMETRICMASK");
     EvHueMask = m->newEvent(EVENT, "HISTORY_MSG_LOCALCONTRAST_HUEMASK");
-    EvChromaticityMask = m->newEvent(EVENT, "HISTORY_MSG_LOCALCONTRAST_CHROMATICITYMASK");
-    EvLightnessMask = m->newEvent(EVENT, "HISTORY_MSG_LOCALCONTRAST_LIGHTNESSMASK");
+    EvChromaticityMask =
+        m->newEvent(EVENT, "HISTORY_MSG_LOCALCONTRAST_CHROMATICITYMASK");
+    EvLightnessMask =
+        m->newEvent(EVENT, "HISTORY_MSG_LOCALCONTRAST_LIGHTNESSMASK");
     EvMaskBlur = m->newEvent(EVENT, "HISTORY_MSG_LOCALCONTRAST_MASKBLUR");
     EvShowMask = m->newEvent(EVENT, "HISTORY_MSG_LOCALCONTRAST_SHOWMASK");
     EvAreaMask = m->newEvent(EVENT, "HISTORY_MSG_LOCALCONTRAST_AREAMASK");
     EvDeltaEMask = m->newEvent(EVENT, "HISTORY_MSG_LOCALCONTRAST_DELTAEMASK");
-    EvContrastThresholdMask = m->newEvent(EVENT, "HISTORY_MSG_LOCALCONTRAST_CONTRASTTHRESHOLDMASK");
+    EvContrastThresholdMask =
+        m->newEvent(EVENT, "HISTORY_MSG_LOCALCONTRAST_CONTRASTTHRESHOLDMASK");
     EvDrawnMask = m->newEvent(EVENT, "HISTORY_MSG_LOCALCONTRAST_DRAWNMASK");
-    EvMaskPostprocess = m->newEvent(EVENT, "HISTORY_MSG_LOCALCONTRAST_MASK_POSTPROCESS");
+    EvMaskPostprocess =
+        m->newEvent(EVENT, "HISTORY_MSG_LOCALCONTRAST_MASK_POSTPROCESS");
     EvLinkedMask = m->newEvent(EVENT, "HISTORY_MSG_LOCALCONTRAST_LINKEDMASK");
-    EvExternalMask = m->newEvent(EVENT, "HISTORY_MSG_LOCALCONTRAST_EXTERNALMASK");
+    EvExternalMask =
+        m->newEvent(EVENT, "HISTORY_MSG_LOCALCONTRAST_EXTERNALMASK");
 
     EvToolEnabled.set_action(EVENT);
     EvToolReset.set_action(EVENT);
-    
+
     box = Gtk::manage(new ToolParamBlock());
 
-    contrast = Gtk::manage(new Adjuster(M("TP_LOCALCONTRAST_CONTRAST"), -100., 100., 0.1, 0.));
+    contrast = Gtk::manage(
+        new Adjuster(M("TP_LOCALCONTRAST_CONTRAST"), -100., 100., 0.1, 0.));
 
     const LocalContrastParams default_params;
-    
-    cg = Gtk::manage(new CurveEditorGroup(options.lastToneCurvesDir, M("TP_LOCALCONTRAST_CURVE"), 0.7));
+
+    cg = Gtk::manage(new CurveEditorGroup(options.lastToneCurvesDir,
+                                          M("TP_LOCALCONTRAST_CURVE"), 0.7));
     cg->setCurveListener(this);
-    curve = static_cast<FlatCurveEditor *>(cg->addCurve(CT_Flat, "", nullptr, false, false));
+    curve = static_cast<FlatCurveEditor *>(
+        cg->addCurve(CT_Flat, "", nullptr, false, false));
     curve->setIdentityValue(0.);
-    curve->setResetCurve(FlatCurveType(default_params.regions[0].curve.at(0)), default_params.regions[0].curve);
+    curve->setResetCurve(FlatCurveType(default_params.regions[0].curve.at(0)),
+                         default_params.regions[0].curve);
     cg->curveListComplete();
     cg->show();
-    
+
     contrast->setAdjusterListener(this);
 
     box->pack_start(*cg);
@@ -220,10 +217,9 @@ LocalContrast::LocalContrast(): FoldableToolPanel(this, "localcontrast", M("TP_L
 
     masks_content_provider_.reset(new LocalContrastMasksContentProvider(this));
     masks_ = Gtk::manage(new MasksPanel(masks_content_provider_.get()));
-    pack_start(*masks_, Gtk::PACK_EXPAND_WIDGET, 4);   
+    pack_start(*masks_, Gtk::PACK_EXPAND_WIDGET, 4);
 }
 
-
 void LocalContrast::read(const ProcParams *pp)
 {
     disableListener();
@@ -233,15 +229,18 @@ void LocalContrast::read(const ProcParams *pp)
 
     auto m = pp->localContrast.masks;
     if (regionData.empty()) {
-        regionData.emplace_back(rtengine::procparams::LocalContrastParams::Region());
+        regionData.emplace_back(
+            rtengine::procparams::LocalContrastParams::Region());
         m.emplace_back(rtengine::procparams::Mask());
     }
-    masks_->setMasks(m, pp->localContrast.selectedRegion, pp->localContrast.showMask >= 0 && pp->localContrast.showMask == pp->localContrast.selectedRegion);
+    masks_->setMasks(m, pp->localContrast.selectedRegion,
+                     pp->localContrast.showMask >= 0 &&
+                         pp->localContrast.showMask ==
+                             pp->localContrast.selectedRegion);
 
     enableListener();
 }
 
-
 void LocalContrast::write(ProcParams *pp)
 {
     pp->localContrast.enabled = getEnabled();
@@ -256,12 +255,14 @@ void LocalContrast::write(ProcParams *pp)
 void LocalContrast::setDefaults(const ProcParams *defParams)
 {
     contrast->setDefault(defParams->localContrast.regions[0].contrast);
-    curve->setResetCurve(FlatCurveType(defParams->localContrast.regions[0].curve.at(0)), defParams->localContrast.regions[0].curve);
+    curve->setResetCurve(
+        FlatCurveType(defParams->localContrast.regions[0].curve.at(0)),
+        defParams->localContrast.regions[0].curve);
 
     initial_params = defParams->localContrast;
 }
 
-void LocalContrast::adjusterChanged(Adjuster* a, double newval)
+void LocalContrast::adjusterChanged(Adjuster *a, double newval)
 {
     if (listener && getEnabled()) {
         if (a == contrast) {
@@ -270,19 +271,20 @@ void LocalContrast::adjusterChanged(Adjuster* a, double newval)
     }
 }
 
-void LocalContrast::adjusterAutoToggled(Adjuster* a, bool newval)
-{
-}
+void LocalContrast::adjusterAutoToggled(Adjuster *a, bool newval) {}
 
-void LocalContrast::enabledChanged ()
+void LocalContrast::enabledChanged()
 {
     if (listener) {
         if (get_inconsistent()) {
-            listener->panelChanged(EvLocalContrastEnabled, M("GENERAL_UNCHANGED"));
+            listener->panelChanged(EvLocalContrastEnabled,
+                                   M("GENERAL_UNCHANGED"));
         } else if (getEnabled()) {
-            listener->panelChanged(EvLocalContrastEnabled, M("GENERAL_ENABLED"));
+            listener->panelChanged(EvLocalContrastEnabled,
+                                   M("GENERAL_ENABLED"));
         } else {
-            listener->panelChanged(EvLocalContrastEnabled, M("GENERAL_DISABLED"));
+            listener->panelChanged(EvLocalContrastEnabled,
+                                   M("GENERAL_DISABLED"));
         }
     }
 
@@ -291,7 +293,6 @@ void LocalContrast::enabledChanged ()
     }
 }
 
-
 void LocalContrast::curveChanged()
 {
     if (listener) {
@@ -299,47 +300,37 @@ void LocalContrast::curveChanged()
     }
 }
 
-
-void LocalContrast::autoOpenCurve()
-{
-    curve->openIfNonlinear();
-}
-
+void LocalContrast::autoOpenCurve() { curve->openIfNonlinear(); }
 
 void LocalContrast::setEditProvider(EditDataProvider *provider)
 {
     masks_->setEditProvider(provider);
 }
 
-
 void LocalContrast::procParamsChanged(
-    const rtengine::procparams::ProcParams* params,
-    const rtengine::ProcEvent& ev,
-    const Glib::ustring& descr,
-    const ParamsEdited* paramsEdited)
+    const rtengine::procparams::ProcParams *params,
+    const rtengine::ProcEvent &ev, const Glib::ustring &descr,
+    const ParamsEdited *paramsEdited)
 {
     masks_->updateLinkedMaskList(params);
 }
 
-
 void LocalContrast::updateGeometry(int fw, int fh)
 {
     masks_->updateGeometry(fw, fh);
 }
 
-
 void LocalContrast::regionGet(int idx)
 {
     if (idx < 0 || size_t(idx) >= regionData.size()) {
         return;
     }
-    
+
     auto &r = regionData[idx];
     r.contrast = contrast->getValue();
     r.curve = curve->getCurve();
 }
 
-
 void LocalContrast::regionShow(int idx)
 {
     const bool disable = listener;
@@ -350,25 +341,22 @@ void LocalContrast::regionShow(int idx)
     auto &r = regionData[idx];
     contrast->setValue(r.contrast);
     curve->setCurve(r.curve);
-    
+
     if (disable) {
         enableListener();
     }
 }
 
-
 void LocalContrast::setAreaDrawListener(AreaDrawListener *l)
 {
     masks_->setAreaDrawListener(l);
 }
 
-
 void LocalContrast::setDeltaEColorProvider(DeltaEColorProvider *p)
 {
     masks_->setDeltaEColorProvider(p);
 }
 
-
 void LocalContrast::toolReset(bool to_initial)
 {
     ProcParams pp;
