@@ -434,6 +434,7 @@ public:
         bool allow_whitespace;
         int on_existing;
         int progressive_number;
+        bool use_basedir;
 
         RenameOptions();
         bool load(Glib::KeyFile &kf);
@@ -475,6 +476,15 @@ public:
     };
     std::map<Glib::ustring, ExportProfileInfo> export_profile_map;
 
+    enum class ViewingConditions {
+        VERY_BRIGHT,
+        BRIGHT,
+        NORMAL,
+        DIM,
+        DARK
+    };
+    ViewingConditions viewing_conditions;
+
     Options();
 
     Options *copyFrom(Options *other);
